from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class AdErrorEnum(proto.Message):
    class AdError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE = 2
        APPROXIMATELY_TOO_LONG = 3
        APPROXIMATELY_TOO_SHORT = 4
        BAD_SNIPPET = 5
        CANNOT_MODIFY_AD = 6
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET = 7
        CANNOT_SET_FIELD = 8
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET = 9
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING = 10
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE = 11
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING = 12
        CANNOT_SET_URL = 13
        CANNOT_SET_WITHOUT_FINAL_URLS = 14
        CANNOT_SET_WITH_FINAL_URLS = 15
        CANNOT_SET_WITH_URL_DATA = 17
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR = 18
        CUSTOMER_NOT_APPROVED_MOBILEADS = 19
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS = 20
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS = 21
        CUSTOMER_NOT_ELIGIBLE = 22
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL = 23
        DIMENSION_ALREADY_IN_UNION = 24
        DIMENSION_MUST_BE_SET = 25
        DIMENSION_NOT_IN_UNION = 26
        DISPLAY_URL_CANNOT_BE_SPECIFIED = 27
        DOMESTIC_PHONE_NUMBER_FORMAT = 28
        EMERGENCY_PHONE_NUMBER = 29
        EMPTY_FIELD = 30
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID = 31
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH = 32
        ILLEGAL_AD_CUSTOMIZER_TAG_USE = 33
        ILLEGAL_TAG_USE = 34
        INCONSISTENT_DIMENSIONS = 35
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION = 36
        INCORRECT_LENGTH = 37
        INELIGIBLE_FOR_UPGRADE = 38
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET = 39
        INVALID_AD_TYPE = 40
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE = 41
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT = 42
        INVALID_CALL_TO_ACTION_TEXT = 43
        INVALID_CHARACTER_FOR_URL = 44
        INVALID_COUNTRY_CODE = 45
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG = 47
        INVALID_INPUT = 48
        INVALID_MARKUP_LANGUAGE = 49
        INVALID_MOBILE_CARRIER = 50
        INVALID_MOBILE_CARRIER_TARGET = 51
        INVALID_NUMBER_OF_ELEMENTS = 52
        INVALID_PHONE_NUMBER_FORMAT = 53
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID = 54
        INVALID_TEMPLATE_DATA = 55
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE = 56
        INVALID_TEMPLATE_ID = 57
        LINE_TOO_WIDE = 58
        MISSING_AD_CUSTOMIZER_MAPPING = 59
        MISSING_ADDRESS_COMPONENT = 60
        MISSING_ADVERTISEMENT_NAME = 61
        MISSING_BUSINESS_NAME = 62
        MISSING_DESCRIPTION1 = 63
        MISSING_DESCRIPTION2 = 64
        MISSING_DESTINATION_URL_TAG = 65
        MISSING_LANDING_PAGE_URL_TAG = 66
        MISSING_DIMENSION = 67
        MISSING_DISPLAY_URL = 68
        MISSING_HEADLINE = 69
        MISSING_HEIGHT = 70
        MISSING_IMAGE = 71
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS = 72
        MISSING_MARKUP_LANGUAGES = 73
        MISSING_MOBILE_CARRIER = 74
        MISSING_PHONE = 75
        MISSING_REQUIRED_TEMPLATE_FIELDS = 76
        MISSING_TEMPLATE_FIELD_VALUE = 77
        MISSING_TEXT = 78
        MISSING_VISIBLE_URL = 79
        MISSING_WIDTH = 80
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED = 81
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD = 82
        TOO_LONG = 83
        TOO_SHORT = 84
        UNION_DIMENSIONS_CANNOT_CHANGE = 85
        UNKNOWN_ADDRESS_COMPONENT = 86
        UNKNOWN_FIELD_NAME = 87
        UNKNOWN_UNIQUE_NAME = 88
        UNSUPPORTED_DIMENSIONS = 89
        URL_INVALID_SCHEME = 90
        URL_INVALID_TOP_LEVEL_DOMAIN = 91
        URL_MALFORMED = 92
        URL_NO_HOST = 93
        URL_NOT_EQUIVALENT = 94
        URL_HOST_NAME_TOO_LONG = 95
        URL_NO_SCHEME = 96
        URL_NO_TOP_LEVEL_DOMAIN = 97
        URL_PATH_NOT_ALLOWED = 98
        URL_PORT_NOT_ALLOWED = 99
        URL_QUERY_NOT_ALLOWED = 100
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG = 102
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE = 103
        INCONSISTENT_EXPANDABLE_SETTINGS = 104
        INVALID_FORMAT = 105
        INVALID_FIELD_TEXT = 106
        ELEMENT_NOT_PRESENT = 107
        IMAGE_ERROR = 108
        VALUE_NOT_IN_RANGE = 109
        FIELD_NOT_PRESENT = 110
        ADDRESS_NOT_COMPLETE = 111
        ADDRESS_INVALID = 112
        VIDEO_RETRIEVAL_ERROR = 113
        AUDIO_ERROR = 114
        INVALID_YOUTUBE_DISPLAY_URL = 115
        TOO_MANY_PRODUCT_IMAGES = 116
        TOO_MANY_PRODUCT_VIDEOS = 117
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE = 118
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = 119
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = 120
        DISALLOWED_NUMBER_TYPE = 121
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = 122
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = 123
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = 124
        VANITY_PHONE_NUMBER_NOT_ALLOWED = 125
        INVALID_CALL_CONVERSION_TYPE_ID = 126
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID = 127
        CANNOT_SET_PATH2_WITHOUT_PATH1 = 128
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME = 129
        INCOMPATIBLE_WITH_RESTRICTION_TYPE = 130
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = 131
        MISSING_IMAGE_OR_MEDIA_BUNDLE = 132
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN = 133
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE = 134
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE = 135
        PLACEHOLDER_DEFAULT_VALUE_MISSING = 136
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE = 137
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT = 138
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION = 139
        CALL_AD_VERIFICATION_URL_FINAL_URL_DOES_NOT_HAVE_SAME_DOMAIN = 140
        CALL_AD_FINAL_URL_AND_VERIFICATION_URL_CANNOT_BOTH_BE_EMPTY = 154
        TOO_MANY_AD_CUSTOMIZERS = 141
        INVALID_AD_CUSTOMIZER_FORMAT = 142
        NESTED_AD_CUSTOMIZER_SYNTAX = 143
        UNSUPPORTED_AD_CUSTOMIZER_SYNTAX = 144
        UNPAIRED_BRACE_IN_AD_CUSTOMIZER_TAG = 145
        MORE_THAN_ONE_COUNTDOWN_TAG_TYPE_EXISTS = 146
        DATE_TIME_IN_COUNTDOWN_TAG_IS_INVALID = 147
        DATE_TIME_IN_COUNTDOWN_TAG_IS_PAST = 148
        UNRECOGNIZED_AD_CUSTOMIZER_TAG_FOUND = 149
        CUSTOMIZER_TYPE_FORBIDDEN_FOR_FIELD = 150
        INVALID_CUSTOMIZER_ATTRIBUTE_NAME = 151
        STORE_MISMATCH = 152
        MISSING_REQUIRED_IMAGE_ASPECT_RATIO = 153
        MISMATCHED_ASPECT_RATIOS = 155
        DUPLICATE_IMAGE_ACROSS_CAROUSEL_CARDS = 156
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask

from google.ads.googleads.v15.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v15.resources.types.asset_group_listing_group_filter import (
    AssetGroupListingGroupFilter,
)

_M = TypeVar("_M")

class AssetGroupListingGroupFilterOperation(proto.Message):
    update_mask: FieldMask
    create: AssetGroupListingGroupFilter
    update: AssetGroupListingGroupFilter
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        update_mask: FieldMask = ...,
        create: AssetGroupListingGroupFilter = ...,
        update: AssetGroupListingGroupFilter = ...,
        remove: str = ...
    ) -> None: ...

class MutateAssetGroupListingGroupFilterResult(proto.Message):
    resource_name: str
    asset_group_listing_group_filter: AssetGroupListingGroupFilter
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        asset_group_listing_group_filter: AssetGroupListingGroupFilter = ...
    ) -> None: ...

class MutateAssetGroupListingGroupFiltersRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[AssetGroupListingGroupFilterOperation]
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        operations: MutableSequence[AssetGroupListingGroupFilterOperation] = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...
    ) -> None: ...

class MutateAssetGroupListingGroupFiltersResponse(proto.Message):
    results: MutableSequence[MutateAssetGroupListingGroupFilterResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        results: MutableSequence[MutateAssetGroupListingGroupFilterResult] = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v13.enums.types.combined_audience_status import (
    CombinedAudienceStatusEnum,
)

_M = TypeVar("_M")

class CombinedAudience(proto.Message):
    resource_name: str
    id: int
    status: CombinedAudienceStatusEnum.CombinedAudienceStatus
    name: str
    description: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        id: int = ...,
        status: CombinedAudienceStatusEnum.CombinedAudienceStatus = ...,
        name: str = ...,
        description: str = ...
    ) -> None: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from google.rpc.status_pb2 import Status

from google.ads.googleads.v14.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v14.resources.types.campaign_draft import CampaignDraft

_M = TypeVar("_M")

class CampaignDraftOperation(proto.Message):
    update_mask: FieldMask
    create: CampaignDraft
    update: CampaignDraft
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        update_mask: FieldMask = ...,
        create: CampaignDraft = ...,
        update: CampaignDraft = ...,
        remove: str = ...
    ) -> None: ...

class ListCampaignDraftAsyncErrorsRequest(proto.Message):
    resource_name: str
    page_token: str
    page_size: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        page_token: str = ...,
        page_size: int = ...
    ) -> None: ...

class ListCampaignDraftAsyncErrorsResponse(proto.Message):
    errors: MutableSequence[Status]
    next_page_token: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        errors: MutableSequence[Status] = ...,
        next_page_token: str = ...
    ) -> None: ...

class MutateCampaignDraftResult(proto.Message):
    resource_name: str
    campaign_draft: CampaignDraft
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        campaign_draft: CampaignDraft = ...
    ) -> None: ...

class MutateCampaignDraftsRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[CampaignDraftOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        operations: MutableSequence[CampaignDraftOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...
    ) -> None: ...

class MutateCampaignDraftsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[MutateCampaignDraftResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        partial_failure_error: Status = ...,
        results: MutableSequence[MutateCampaignDraftResult] = ...
    ) -> None: ...

class PromoteCampaignDraftRequest(proto.Message):
    campaign_draft: str
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        campaign_draft: str = ...,
        validate_only: bool = ...
    ) -> None: ...



import logging
from typing import Callable, TypeVar

import grpc
from google.protobuf.message import Message

from google.ads.googleads import v13, v14, v15

from .interceptor import Interceptor

_Request = TypeVar(
    "_Request",
    v13.SearchGoogleAdsRequest,
    v13.SearchGoogleAdsStreamRequest,
    v14.SearchGoogleAdsRequest,
    v14.SearchGoogleAdsStreamRequest,
    v15.SearchGoogleAdsRequest,
    v15.SearchGoogleAdsStreamRequest,
)
_Response = TypeVar("_Response")

class LoggingInterceptor(
    Interceptor, grpc.UnaryUnaryClientInterceptor, grpc.UnaryStreamClientInterceptor
):
    endpoint: str = ...
    logger: logging.Logger = ...
    def __init__(
        self, logger: logging.Logger, api_version: str, endpoint: str | None = ...
    ) -> None: ...
    def log_successful_request(
        self,
        method: str | None,
        customer_id: str | None,
        metadata_json: str,
        request_id: str | None,
        request: _Request,
        trailing_metadata_json: str,
        response: _Response,
    ) -> None: ...
    def log_failed_request(
        self,
        method: str | None,
        customer_id: str | None,
        metadata_json: str,
        request_id: str | None,
        request: _Request,
        trailing_metadata_json: str,
        response: _Response,
    ) -> None: ...
    def log_request(
        self,
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
        response: _Response,
    ) -> None: ...
    def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...
    def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...
    def retrieve_and_mask_result(self, response: _Response) -> Message: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v13.enums.types.listing_group_filter_bidding_category_level import (
    ListingGroupFilterBiddingCategoryLevelEnum,
)
from google.ads.googleads.v13.enums.types.listing_group_filter_custom_attribute_index import (
    ListingGroupFilterCustomAttributeIndexEnum,
)
from google.ads.googleads.v13.enums.types.listing_group_filter_product_channel import (
    ListingGroupFilterProductChannelEnum,
)
from google.ads.googleads.v13.enums.types.listing_group_filter_product_condition import (
    ListingGroupFilterProductConditionEnum,
)
from google.ads.googleads.v13.enums.types.listing_group_filter_product_type_level import (
    ListingGroupFilterProductTypeLevelEnum,
)
from google.ads.googleads.v13.enums.types.listing_group_filter_type_enum import (
    ListingGroupFilterTypeEnum,
)
from google.ads.googleads.v13.enums.types.listing_group_filter_vertical import (
    ListingGroupFilterVerticalEnum,
)

_M = TypeVar("_M")

class AssetGroupListingGroupFilter(proto.Message):
    resource_name: str
    asset_group: str
    id: int
    type_: ListingGroupFilterTypeEnum.ListingGroupFilterType
    vertical: ListingGroupFilterVerticalEnum.ListingGroupFilterVertical
    case_value: ListingGroupFilterDimension
    parent_listing_group_filter: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        asset_group: str = ...,
        id: int = ...,
        type_: ListingGroupFilterTypeEnum.ListingGroupFilterType = ...,
        vertical: ListingGroupFilterVerticalEnum.ListingGroupFilterVertical = ...,
        case_value: ListingGroupFilterDimension = ...,
        parent_listing_group_filter: str = ...
    ) -> None: ...

class ListingGroupFilterDimension(proto.Message):
    class ProductBiddingCategory(proto.Message):
        id: int
        level: ListingGroupFilterBiddingCategoryLevelEnum.ListingGroupFilterBiddingCategoryLevel
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            id: int = ...,
            level: ListingGroupFilterBiddingCategoryLevelEnum.ListingGroupFilterBiddingCategoryLevel = ...
        ) -> None: ...

    class ProductBrand(proto.Message):
        value: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            value: str = ...
        ) -> None: ...

    class ProductChannel(proto.Message):
        channel: ListingGroupFilterProductChannelEnum.ListingGroupFilterProductChannel
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            channel: ListingGroupFilterProductChannelEnum.ListingGroupFilterProductChannel = ...
        ) -> None: ...

    class ProductCondition(proto.Message):
        condition: ListingGroupFilterProductConditionEnum.ListingGroupFilterProductCondition
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            condition: ListingGroupFilterProductConditionEnum.ListingGroupFilterProductCondition = ...
        ) -> None: ...

    class ProductCustomAttribute(proto.Message):
        value: str
        index: ListingGroupFilterCustomAttributeIndexEnum.ListingGroupFilterCustomAttributeIndex
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            value: str = ...,
            index: ListingGroupFilterCustomAttributeIndexEnum.ListingGroupFilterCustomAttributeIndex = ...
        ) -> None: ...

    class ProductItemId(proto.Message):
        value: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            value: str = ...
        ) -> None: ...

    class ProductType(proto.Message):
        value: str
        level: ListingGroupFilterProductTypeLevelEnum.ListingGroupFilterProductTypeLevel
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
            *,
            ignore_unknown_fields: bool = ...,
            value: str = ...,
            level: ListingGroupFilterProductTypeLevelEnum.ListingGroupFilterProductTypeLevel = ...
        ) -> None: ...
    product_bidding_category: ListingGroupFilterDimension.ProductBiddingCategory
    product_brand: ListingGroupFilterDimension.ProductBrand
    product_channel: ListingGroupFilterDimension.ProductChannel
    product_condition: ListingGroupFilterDimension.ProductCondition
    product_custom_attribute: ListingGroupFilterDimension.ProductCustomAttribute
    product_item_id: ListingGroupFilterDimension.ProductItemId
    product_type: ListingGroupFilterDimension.ProductType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        product_bidding_category: ListingGroupFilterDimension.ProductBiddingCategory = ...,
        product_brand: ListingGroupFilterDimension.ProductBrand = ...,
        product_channel: ListingGroupFilterDimension.ProductChannel = ...,
        product_condition: ListingGroupFilterDimension.ProductCondition = ...,
        product_custom_attribute: ListingGroupFilterDimension.ProductCustomAttribute = ...,
        product_item_id: ListingGroupFilterDimension.ProductItemId = ...,
        product_type: ListingGroupFilterDimension.ProductType = ...
    ) -> None: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status

from google.ads.googleads.v14.common.types.offline_user_data import UserIdentifier
from google.ads.googleads.v14.enums.types.conversion_adjustment_type import (
    ConversionAdjustmentTypeEnum,
)

_M = TypeVar("_M")

class ConversionAdjustment(proto.Message):
    gclid_date_time_pair: GclidDateTimePair
    order_id: str
    conversion_action: str
    adjustment_date_time: str
    adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType
    restatement_value: RestatementValue
    user_identifiers: MutableSequence[UserIdentifier]
    user_agent: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        gclid_date_time_pair: GclidDateTimePair = ...,
        order_id: str = ...,
        conversion_action: str = ...,
        adjustment_date_time: str = ...,
        adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType = ...,
        restatement_value: RestatementValue = ...,
        user_identifiers: MutableSequence[UserIdentifier] = ...,
        user_agent: str = ...
    ) -> None: ...

class ConversionAdjustmentResult(proto.Message):
    gclid_date_time_pair: GclidDateTimePair
    order_id: str
    conversion_action: str
    adjustment_date_time: str
    adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        gclid_date_time_pair: GclidDateTimePair = ...,
        order_id: str = ...,
        conversion_action: str = ...,
        adjustment_date_time: str = ...,
        adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType = ...
    ) -> None: ...

class GclidDateTimePair(proto.Message):
    gclid: str
    conversion_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        gclid: str = ...,
        conversion_date_time: str = ...
    ) -> None: ...

class RestatementValue(proto.Message):
    adjusted_value: float
    currency_code: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        adjusted_value: float = ...,
        currency_code: str = ...
    ) -> None: ...

class UploadConversionAdjustmentsRequest(proto.Message):
    customer_id: str
    conversion_adjustments: MutableSequence[ConversionAdjustment]
    partial_failure: bool
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        conversion_adjustments: MutableSequence[ConversionAdjustment] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...
    ) -> None: ...

class UploadConversionAdjustmentsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[ConversionAdjustmentResult]
    job_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        partial_failure_error: Status = ...,
        results: MutableSequence[ConversionAdjustmentResult] = ...,
        job_id: int = ...
    ) -> None: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v14.enums.types.keyword_plan_network import (
    KeywordPlanNetworkEnum,
)

_M = TypeVar("_M")

class KeywordPlanCampaign(proto.Message):
    resource_name: str
    keyword_plan: str
    id: int
    name: str
    language_constants: MutableSequence[str]
    keyword_plan_network: KeywordPlanNetworkEnum.KeywordPlanNetwork
    cpc_bid_micros: int
    geo_targets: MutableSequence[KeywordPlanGeoTarget]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        keyword_plan: str = ...,
        id: int = ...,
        name: str = ...,
        language_constants: MutableSequence[str] = ...,
        keyword_plan_network: KeywordPlanNetworkEnum.KeywordPlanNetwork = ...,
        cpc_bid_micros: int = ...,
        geo_targets: MutableSequence[KeywordPlanGeoTarget] = ...
    ) -> None: ...

class KeywordPlanGeoTarget(proto.Message):
    geo_target_constant: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        geo_target_constant: str = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v15.common.types.simulation import (
    CpcBidSimulationPointList,
    CpvBidSimulationPointList,
    TargetCpaSimulationPointList,
    TargetRoasSimulationPointList,
)
from google.ads.googleads.v15.enums.types.simulation_modification_method import (
    SimulationModificationMethodEnum,
)
from google.ads.googleads.v15.enums.types.simulation_type import SimulationTypeEnum

_M = TypeVar("_M")

class AdGroupSimulation(proto.Message):
    resource_name: str
    ad_group_id: int
    type_: SimulationTypeEnum.SimulationType
    modification_method: SimulationModificationMethodEnum.SimulationModificationMethod
    start_date: str
    end_date: str
    cpc_bid_point_list: CpcBidSimulationPointList
    cpv_bid_point_list: CpvBidSimulationPointList
    target_cpa_point_list: TargetCpaSimulationPointList
    target_roas_point_list: TargetRoasSimulationPointList
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        ad_group_id: int = ...,
        type_: SimulationTypeEnum.SimulationType = ...,
        modification_method: SimulationModificationMethodEnum.SimulationModificationMethod = ...,
        start_date: str = ...,
        end_date: str = ...,
        cpc_bid_point_list: CpcBidSimulationPointList = ...,
        cpv_bid_point_list: CpvBidSimulationPointList = ...,
        target_cpa_point_list: TargetCpaSimulationPointList = ...,
        target_roas_point_list: TargetRoasSimulationPointList = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class ServedAssetFieldTypeEnum(proto.Message):
    class ServedAssetFieldType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        HEADLINE_1 = 2
        HEADLINE_2 = 3
        HEADLINE_3 = 4
        DESCRIPTION_1 = 5
        DESCRIPTION_2 = 6
        HEADLINE = 7
        HEADLINE_IN_PORTRAIT = 8
        LONG_HEADLINE = 9
        DESCRIPTION = 10
        DESCRIPTION_IN_PORTRAIT = 11
        BUSINESS_NAME_IN_PORTRAIT = 12
        BUSINESS_NAME = 13
        MARKETING_IMAGE = 14
        MARKETING_IMAGE_IN_PORTRAIT = 15
        SQUARE_MARKETING_IMAGE = 16
        PORTRAIT_MARKETING_IMAGE = 17
        LOGO = 18
        LANDSCAPE_LOGO = 19
        CALL_TO_ACTION = 20
        YOU_TUBE_VIDEO = 21
        SITELINK = 22
        CALL = 23
        MOBILE_APP = 24
        CALLOUT = 25
        STRUCTURED_SNIPPET = 26
        PRICE = 27
        PROMOTION = 28
        AD_IMAGE = 29
        LEAD_FORM = 30
        BUSINESS_LOGO = 31
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v14.enums.types.target_frequency_time_unit import (
    TargetFrequencyTimeUnitEnum,
)
from google.ads.googleads.v14.enums.types.target_impression_share_location import (
    TargetImpressionShareLocationEnum,
)

_M = TypeVar("_M")

class Commission(proto.Message):
    commission_rate_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        commission_rate_micros: int = ...,
    ) -> None: ...

class EnhancedCpc(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...
    ...

class ManualCpa(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...
    ...

class ManualCpc(proto.Message):
    enhanced_cpc_enabled: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        enhanced_cpc_enabled: bool = ...,
    ) -> None: ...

class ManualCpm(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...
    ...

class ManualCpv(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...
    ...

class MaximizeConversionValue(proto.Message):
    target_roas: float
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        target_roas: float = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
    ) -> None: ...

class MaximizeConversions(proto.Message):
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    target_cpa_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
        target_cpa_micros: int = ...,
    ) -> None: ...

class PercentCpc(proto.Message):
    cpc_bid_ceiling_micros: int
    enhanced_cpc_enabled: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        cpc_bid_ceiling_micros: int = ...,
        enhanced_cpc_enabled: bool = ...,
    ) -> None: ...

class TargetCpa(proto.Message):
    target_cpa_micros: int
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        target_cpa_micros: int = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
    ) -> None: ...

class TargetCpm(proto.Message):
    target_frequency_goal: TargetCpmTargetFrequencyGoal
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        target_frequency_goal: TargetCpmTargetFrequencyGoal = ...,
    ) -> None: ...

class TargetCpmTargetFrequencyGoal(proto.Message):
    target_count: int
    time_unit: TargetFrequencyTimeUnitEnum.TargetFrequencyTimeUnit
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        target_count: int = ...,
        time_unit: TargetFrequencyTimeUnitEnum.TargetFrequencyTimeUnit = ...,
    ) -> None: ...

class TargetImpressionShare(proto.Message):
    location: TargetImpressionShareLocationEnum.TargetImpressionShareLocation
    location_fraction_micros: int
    cpc_bid_ceiling_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        location: TargetImpressionShareLocationEnum.TargetImpressionShareLocation = ...,
        location_fraction_micros: int = ...,
        cpc_bid_ceiling_micros: int = ...,
    ) -> None: ...

class TargetRoas(proto.Message):
    target_roas: float
    cpc_bid_ceiling_micros: int
    cpc_bid_floor_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        target_roas: float = ...,
        cpc_bid_ceiling_micros: int = ...,
        cpc_bid_floor_micros: int = ...,
    ) -> None: ...

class TargetSpend(proto.Message):
    target_spend_micros: int
    cpc_bid_ceiling_micros: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        target_spend_micros: int = ...,
        cpc_bid_ceiling_micros: int = ...,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class ConversionAdjustmentUploadErrorEnum(proto.Message):
    class ConversionAdjustmentUploadError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        TOO_RECENT_CONVERSION_ACTION = 2
        CONVERSION_ALREADY_RETRACTED = 4
        CONVERSION_NOT_FOUND = 5
        CONVERSION_EXPIRED = 6
        ADJUSTMENT_PRECEDES_CONVERSION = 7
        MORE_RECENT_RESTATEMENT_FOUND = 8
        TOO_RECENT_CONVERSION = 9
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = 10
        TOO_MANY_ADJUSTMENTS_IN_REQUEST = 11
        TOO_MANY_ADJUSTMENTS = 12
        RESTATEMENT_ALREADY_EXISTS = 13
        DUPLICATE_ADJUSTMENT_IN_REQUEST = 14
        CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS = 15
        CONVERSION_ACTION_NOT_ELIGIBLE_FOR_ENHANCEMENT = 16
        INVALID_USER_IDENTIFIER = 17
        UNSUPPORTED_USER_IDENTIFIER = 18
        GCLID_DATE_TIME_PAIR_AND_ORDER_ID_BOTH_SET = 20
        CONVERSION_ALREADY_ENHANCED = 21
        DUPLICATE_ENHANCEMENT_IN_REQUEST = 22
        CUSTOMER_DATA_POLICY_PROHIBITS_ENHANCEMENT = 23
        MISSING_ORDER_ID_FOR_WEBPAGE = 24
        ORDER_ID_CONTAINS_PII = 25
        INVALID_JOB_ID = 26
        NO_CONVERSION_ACTION_FOUND = 27
        INVALID_CONVERSION_ACTION_TYPE = 28
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class PriceExtensionTypeEnum(proto.Message):
    class PriceExtensionType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        BRANDS = 2
        EVENTS = 3
        LOCATIONS = 4
        NEIGHBORHOODS = 5
        PRODUCT_CATEGORIES = 6
        PRODUCT_TIERS = 7
        SERVICES = 8
        SERVICE_CATEGORIES = 9
        SERVICE_TIERS = 10
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from .base import (
    CustomerUserAccessInvitationServiceTransport as CustomerUserAccessInvitationServiceTransport,
)
from .grpc import (
    CustomerUserAccessInvitationServiceGrpcTransport as CustomerUserAccessInvitationServiceGrpcTransport,
)



from .base import (
    KeywordPlanCampaignServiceTransport as KeywordPlanCampaignServiceTransport,
)
from .grpc import (
    KeywordPlanCampaignServiceGrpcTransport as KeywordPlanCampaignServiceGrpcTransport,
)



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class RequestErrorEnum(proto.Message):
    class RequestError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        RESOURCE_NAME_MISSING = 3
        RESOURCE_NAME_MALFORMED = 4
        BAD_RESOURCE_ID = 17
        INVALID_CUSTOMER_ID = 16
        OPERATION_REQUIRED = 5
        RESOURCE_NOT_FOUND = 6
        INVALID_PAGE_TOKEN = 7
        EXPIRED_PAGE_TOKEN = 8
        INVALID_PAGE_SIZE = 22
        REQUIRED_FIELD_MISSING = 9
        IMMUTABLE_FIELD = 11
        TOO_MANY_MUTATE_OPERATIONS = 13
        CANNOT_BE_EXECUTED_BY_MANAGER_ACCOUNT = 14
        CANNOT_MODIFY_FOREIGN_FIELD = 15
        INVALID_ENUM_VALUE = 18
        DEVELOPER_TOKEN_PARAMETER_MISSING = 19
        LOGIN_CUSTOMER_ID_PARAMETER_MISSING = 20
        VALIDATE_ONLY_REQUEST_HAS_PAGE_TOKEN = 21
        CANNOT_RETURN_SUMMARY_ROW_FOR_REQUEST_WITHOUT_METRICS = 29
        CANNOT_RETURN_SUMMARY_ROW_FOR_VALIDATE_ONLY_REQUESTS = 30
        INCONSISTENT_RETURN_SUMMARY_ROW_VALUE = 31
        TOTAL_RESULTS_COUNT_NOT_ORIGINALLY_REQUESTED = 32
        RPC_DEADLINE_TOO_SHORT = 33
        UNSUPPORTED_VERSION = 38
        CLOUD_PROJECT_NOT_FOUND = 39
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from .base import (
    KeywordPlanAdGroupServiceTransport as KeywordPlanAdGroupServiceTransport,
)
from .grpc import (
    KeywordPlanAdGroupServiceGrpcTransport as KeywordPlanAdGroupServiceGrpcTransport,
)



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class AdDestinationTypeEnum(proto.Message):
    class AdDestinationType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        NOT_APPLICABLE = 2
        WEBSITE = 3
        APP_DEEP_LINK = 4
        APP_STORE = 5
        PHONE_CALL = 6
        MAP_DIRECTIONS = 7
        LOCATION_LISTING = 8
        MESSAGE = 9
        LEAD_FORM = 10
        YOUTUBE = 11
        UNMODELED_FOR_CONVERSIONS = 12
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class ChangeStatusResourceTypeEnum(proto.Message):
    class ChangeStatusResourceType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        AD_GROUP = 3
        AD_GROUP_AD = 4
        AD_GROUP_CRITERION = 5
        CAMPAIGN = 6
        CAMPAIGN_CRITERION = 7
        FEED = 9
        FEED_ITEM = 10
        AD_GROUP_FEED = 11
        CAMPAIGN_FEED = 12
        AD_GROUP_BID_MODIFIER = 13
        SHARED_SET = 14
        CAMPAIGN_SHARED_SET = 15
        ASSET = 16
        CUSTOMER_ASSET = 17
        CAMPAIGN_ASSET = 18
        AD_GROUP_ASSET = 19
        COMBINED_AUDIENCE = 20
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from .base import (
    CustomerCustomizerServiceTransport as CustomerCustomizerServiceTransport,
)
from .grpc import (
    CustomerCustomizerServiceGrpcTransport as CustomerCustomizerServiceGrpcTransport,
)



from collections.abc import Mapping, MutableSequence
from typing import Any, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from google.rpc.status_pb2 import Status

from google.ads.googleads.v15.common.types.metrics import Metrics
from google.ads.googleads.v15.common.types.segments import Segments
from google.ads.googleads.v15.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v15.enums.types.summary_row_setting import (
    SummaryRowSettingEnum,
)
from google.ads.googleads.v15.resources.types.accessible_bidding_strategy import (
    AccessibleBiddingStrategy,
)
from google.ads.googleads.v15.resources.types.account_budget import AccountBudget
from google.ads.googleads.v15.resources.types.account_budget_proposal import (
    AccountBudgetProposal,
)
from google.ads.googleads.v15.resources.types.account_link import AccountLink
from google.ads.googleads.v15.resources.types.ad_group import AdGroup
from google.ads.googleads.v15.resources.types.ad_group_ad import AdGroupAd
from google.ads.googleads.v15.resources.types.ad_group_ad_asset_combination_view import (
    AdGroupAdAssetCombinationView,
)
from google.ads.googleads.v15.resources.types.ad_group_ad_asset_view import (
    AdGroupAdAssetView,
)
from google.ads.googleads.v15.resources.types.ad_group_ad_label import AdGroupAdLabel
from google.ads.googleads.v15.resources.types.ad_group_asset import AdGroupAsset
from google.ads.googleads.v15.resources.types.ad_group_asset_set import AdGroupAssetSet
from google.ads.googleads.v15.resources.types.ad_group_audience_view import (
    AdGroupAudienceView,
)
from google.ads.googleads.v15.resources.types.ad_group_bid_modifier import (
    AdGroupBidModifier,
)
from google.ads.googleads.v15.resources.types.ad_group_criterion import AdGroupCriterion
from google.ads.googleads.v15.resources.types.ad_group_criterion_customizer import (
    AdGroupCriterionCustomizer,
)
from google.ads.googleads.v15.resources.types.ad_group_criterion_label import (
    AdGroupCriterionLabel,
)
from google.ads.googleads.v15.resources.types.ad_group_criterion_simulation import (
    AdGroupCriterionSimulation,
)
from google.ads.googleads.v15.resources.types.ad_group_customizer import (
    AdGroupCustomizer,
)
from google.ads.googleads.v15.resources.types.ad_group_extension_setting import (
    AdGroupExtensionSetting,
)
from google.ads.googleads.v15.resources.types.ad_group_feed import AdGroupFeed
from google.ads.googleads.v15.resources.types.ad_group_label import AdGroupLabel
from google.ads.googleads.v15.resources.types.ad_group_simulation import (
    AdGroupSimulation,
)
from google.ads.googleads.v15.resources.types.ad_parameter import AdParameter
from google.ads.googleads.v15.resources.types.ad_schedule_view import AdScheduleView
from google.ads.googleads.v15.resources.types.age_range_view import AgeRangeView
from google.ads.googleads.v15.resources.types.android_privacy_shared_key_google_ad_group import (
    AndroidPrivacySharedKeyGoogleAdGroup,
)
from google.ads.googleads.v15.resources.types.android_privacy_shared_key_google_campaign import (
    AndroidPrivacySharedKeyGoogleCampaign,
)
from google.ads.googleads.v15.resources.types.android_privacy_shared_key_google_network_type import (
    AndroidPrivacySharedKeyGoogleNetworkType,
)
from google.ads.googleads.v15.resources.types.asset import Asset
from google.ads.googleads.v15.resources.types.asset_field_type_view import (
    AssetFieldTypeView,
)
from google.ads.googleads.v15.resources.types.asset_group import AssetGroup
from google.ads.googleads.v15.resources.types.asset_group_asset import AssetGroupAsset
from google.ads.googleads.v15.resources.types.asset_group_listing_group_filter import (
    AssetGroupListingGroupFilter,
)
from google.ads.googleads.v15.resources.types.asset_group_product_group_view import (
    AssetGroupProductGroupView,
)
from google.ads.googleads.v15.resources.types.asset_group_signal import AssetGroupSignal
from google.ads.googleads.v15.resources.types.asset_group_top_combination_view import (
    AssetGroupTopCombinationView,
)
from google.ads.googleads.v15.resources.types.asset_set import AssetSet
from google.ads.googleads.v15.resources.types.asset_set_asset import AssetSetAsset
from google.ads.googleads.v15.resources.types.asset_set_type_view import (
    AssetSetTypeView,
)
from google.ads.googleads.v15.resources.types.audience import Audience
from google.ads.googleads.v15.resources.types.batch_job import BatchJob
from google.ads.googleads.v15.resources.types.bidding_data_exclusion import (
    BiddingDataExclusion,
)
from google.ads.googleads.v15.resources.types.bidding_seasonality_adjustment import (
    BiddingSeasonalityAdjustment,
)
from google.ads.googleads.v15.resources.types.bidding_strategy import BiddingStrategy
from google.ads.googleads.v15.resources.types.bidding_strategy_simulation import (
    BiddingStrategySimulation,
)
from google.ads.googleads.v15.resources.types.billing_setup import BillingSetup
from google.ads.googleads.v15.resources.types.call_view import CallView
from google.ads.googleads.v15.resources.types.campaign import Campaign
from google.ads.googleads.v15.resources.types.campaign_asset import CampaignAsset
from google.ads.googleads.v15.resources.types.campaign_asset_set import CampaignAssetSet
from google.ads.googleads.v15.resources.types.campaign_audience_view import (
    CampaignAudienceView,
)
from google.ads.googleads.v15.resources.types.campaign_bid_modifier import (
    CampaignBidModifier,
)
from google.ads.googleads.v15.resources.types.campaign_budget import CampaignBudget
from google.ads.googleads.v15.resources.types.campaign_conversion_goal import (
    CampaignConversionGoal,
)
from google.ads.googleads.v15.resources.types.campaign_criterion import (
    CampaignCriterion,
)
from google.ads.googleads.v15.resources.types.campaign_customizer import (
    CampaignCustomizer,
)
from google.ads.googleads.v15.resources.types.campaign_draft import CampaignDraft
from google.ads.googleads.v15.resources.types.campaign_extension_setting import (
    CampaignExtensionSetting,
)
from google.ads.googleads.v15.resources.types.campaign_feed import CampaignFeed
from google.ads.googleads.v15.resources.types.campaign_group import CampaignGroup
from google.ads.googleads.v15.resources.types.campaign_label import CampaignLabel
from google.ads.googleads.v15.resources.types.campaign_lifecycle_goal import (
    CampaignLifecycleGoal,
)
from google.ads.googleads.v15.resources.types.campaign_search_term_insight import (
    CampaignSearchTermInsight,
)
from google.ads.googleads.v15.resources.types.campaign_shared_set import (
    CampaignSharedSet,
)
from google.ads.googleads.v15.resources.types.campaign_simulation import (
    CampaignSimulation,
)
from google.ads.googleads.v15.resources.types.carrier_constant import CarrierConstant
from google.ads.googleads.v15.resources.types.change_event import ChangeEvent
from google.ads.googleads.v15.resources.types.change_status import ChangeStatus
from google.ads.googleads.v15.resources.types.click_view import ClickView
from google.ads.googleads.v15.resources.types.combined_audience import CombinedAudience
from google.ads.googleads.v15.resources.types.conversion_action import ConversionAction
from google.ads.googleads.v15.resources.types.conversion_custom_variable import (
    ConversionCustomVariable,
)
from google.ads.googleads.v15.resources.types.conversion_goal_campaign_config import (
    ConversionGoalCampaignConfig,
)
from google.ads.googleads.v15.resources.types.conversion_value_rule import (
    ConversionValueRule,
)
from google.ads.googleads.v15.resources.types.conversion_value_rule_set import (
    ConversionValueRuleSet,
)
from google.ads.googleads.v15.resources.types.currency_constant import CurrencyConstant
from google.ads.googleads.v15.resources.types.custom_audience import CustomAudience
from google.ads.googleads.v15.resources.types.custom_conversion_goal import (
    CustomConversionGoal,
)
from google.ads.googleads.v15.resources.types.custom_interest import CustomInterest
from google.ads.googleads.v15.resources.types.customer import Customer
from google.ads.googleads.v15.resources.types.customer_asset import CustomerAsset
from google.ads.googleads.v15.resources.types.customer_asset_set import CustomerAssetSet
from google.ads.googleads.v15.resources.types.customer_client import CustomerClient
from google.ads.googleads.v15.resources.types.customer_client_link import (
    CustomerClientLink,
)
from google.ads.googleads.v15.resources.types.customer_conversion_goal import (
    CustomerConversionGoal,
)
from google.ads.googleads.v15.resources.types.customer_customizer import (
    CustomerCustomizer,
)
from google.ads.googleads.v15.resources.types.customer_extension_setting import (
    CustomerExtensionSetting,
)
from google.ads.googleads.v15.resources.types.customer_feed import CustomerFeed
from google.ads.googleads.v15.resources.types.customer_label import CustomerLabel
from google.ads.googleads.v15.resources.types.customer_lifecycle_goal import (
    CustomerLifecycleGoal,
)
from google.ads.googleads.v15.resources.types.customer_manager_link import (
    CustomerManagerLink,
)
from google.ads.googleads.v15.resources.types.customer_negative_criterion import (
    CustomerNegativeCriterion,
)
from google.ads.googleads.v15.resources.types.customer_search_term_insight import (
    CustomerSearchTermInsight,
)
from google.ads.googleads.v15.resources.types.customer_user_access import (
    CustomerUserAccess,
)
from google.ads.googleads.v15.resources.types.customer_user_access_invitation import (
    CustomerUserAccessInvitation,
)
from google.ads.googleads.v15.resources.types.customizer_attribute import (
    CustomizerAttribute,
)
from google.ads.googleads.v15.resources.types.detail_placement_view import (
    DetailPlacementView,
)
from google.ads.googleads.v15.resources.types.detailed_demographic import (
    DetailedDemographic,
)
from google.ads.googleads.v15.resources.types.display_keyword_view import (
    DisplayKeywordView,
)
from google.ads.googleads.v15.resources.types.distance_view import DistanceView
from google.ads.googleads.v15.resources.types.domain_category import DomainCategory
from google.ads.googleads.v15.resources.types.dynamic_search_ads_search_term_view import (
    DynamicSearchAdsSearchTermView,
)
from google.ads.googleads.v15.resources.types.expanded_landing_page_view import (
    ExpandedLandingPageView,
)
from google.ads.googleads.v15.resources.types.experiment import Experiment
from google.ads.googleads.v15.resources.types.experiment_arm import ExperimentArm
from google.ads.googleads.v15.resources.types.extension_feed_item import (
    ExtensionFeedItem,
)
from google.ads.googleads.v15.resources.types.feed import Feed
from google.ads.googleads.v15.resources.types.feed_item import FeedItem
from google.ads.googleads.v15.resources.types.feed_item_set import FeedItemSet
from google.ads.googleads.v15.resources.types.feed_item_set_link import FeedItemSetLink
from google.ads.googleads.v15.resources.types.feed_item_target import FeedItemTarget
from google.ads.googleads.v15.resources.types.feed_mapping import FeedMapping
from google.ads.googleads.v15.resources.types.feed_placeholder_view import (
    FeedPlaceholderView,
)
from google.ads.googleads.v15.resources.types.gender_view import GenderView
from google.ads.googleads.v15.resources.types.geo_target_constant import (
    GeoTargetConstant,
)
from google.ads.googleads.v15.resources.types.geographic_view import GeographicView
from google.ads.googleads.v15.resources.types.group_placement_view import (
    GroupPlacementView,
)
from google.ads.googleads.v15.resources.types.hotel_group_view import HotelGroupView
from google.ads.googleads.v15.resources.types.hotel_performance_view import (
    HotelPerformanceView,
)
from google.ads.googleads.v15.resources.types.hotel_reconciliation import (
    HotelReconciliation,
)
from google.ads.googleads.v15.resources.types.income_range_view import IncomeRangeView
from google.ads.googleads.v15.resources.types.keyword_plan import KeywordPlan
from google.ads.googleads.v15.resources.types.keyword_plan_ad_group import (
    KeywordPlanAdGroup,
)
from google.ads.googleads.v15.resources.types.keyword_plan_ad_group_keyword import (
    KeywordPlanAdGroupKeyword,
)
from google.ads.googleads.v15.resources.types.keyword_plan_campaign import (
    KeywordPlanCampaign,
)
from google.ads.googleads.v15.resources.types.keyword_plan_campaign_keyword import (
    KeywordPlanCampaignKeyword,
)
from google.ads.googleads.v15.resources.types.keyword_theme_constant import (
    KeywordThemeConstant,
)
from google.ads.googleads.v15.resources.types.keyword_view import KeywordView
from google.ads.googleads.v15.resources.types.label import Label
from google.ads.googleads.v15.resources.types.landing_page_view import LandingPageView
from google.ads.googleads.v15.resources.types.language_constant import LanguageConstant
from google.ads.googleads.v15.resources.types.lead_form_submission_data import (
    LeadFormSubmissionData,
)
from google.ads.googleads.v15.resources.types.life_event import LifeEvent
from google.ads.googleads.v15.resources.types.local_services_lead import (
    LocalServicesLead,
)
from google.ads.googleads.v15.resources.types.local_services_lead_conversation import (
    LocalServicesLeadConversation,
)
from google.ads.googleads.v15.resources.types.local_services_verification_artifact import (
    LocalServicesVerificationArtifact,
)
from google.ads.googleads.v15.resources.types.location_view import LocationView
from google.ads.googleads.v15.resources.types.managed_placement_view import (
    ManagedPlacementView,
)
from google.ads.googleads.v15.resources.types.media_file import MediaFile
from google.ads.googleads.v15.resources.types.mobile_app_category_constant import (
    MobileAppCategoryConstant,
)
from google.ads.googleads.v15.resources.types.mobile_device_constant import (
    MobileDeviceConstant,
)
from google.ads.googleads.v15.resources.types.offline_conversion_upload_client_summary import (
    OfflineConversionUploadClientSummary,
)
from google.ads.googleads.v15.resources.types.offline_user_data_job import (
    OfflineUserDataJob,
)
from google.ads.googleads.v15.resources.types.operating_system_version_constant import (
    OperatingSystemVersionConstant,
)
from google.ads.googleads.v15.resources.types.paid_organic_search_term_view import (
    PaidOrganicSearchTermView,
)
from google.ads.googleads.v15.resources.types.parental_status_view import (
    ParentalStatusView,
)
from google.ads.googleads.v15.resources.types.per_store_view import PerStoreView
from google.ads.googleads.v15.resources.types.product_category_constant import (
    ProductCategoryConstant,
)
from google.ads.googleads.v15.resources.types.product_group_view import ProductGroupView
from google.ads.googleads.v15.resources.types.product_link import ProductLink
from google.ads.googleads.v15.resources.types.product_link_invitation import (
    ProductLinkInvitation,
)
from google.ads.googleads.v15.resources.types.qualifying_question import (
    QualifyingQuestion,
)
from google.ads.googleads.v15.resources.types.recommendation import Recommendation
from google.ads.googleads.v15.resources.types.recommendation_subscription import (
    RecommendationSubscription,
)
from google.ads.googleads.v15.resources.types.remarketing_action import (
    RemarketingAction,
)
from google.ads.googleads.v15.resources.types.search_term_view import SearchTermView
from google.ads.googleads.v15.resources.types.shared_criterion import SharedCriterion
from google.ads.googleads.v15.resources.types.shared_set import SharedSet
from google.ads.googleads.v15.resources.types.shopping_performance_view import (
    ShoppingPerformanceView,
)
from google.ads.googleads.v15.resources.types.smart_campaign_search_term_view import (
    SmartCampaignSearchTermView,
)
from google.ads.googleads.v15.resources.types.smart_campaign_setting import (
    SmartCampaignSetting,
)
from google.ads.googleads.v15.resources.types.third_party_app_analytics_link import (
    ThirdPartyAppAnalyticsLink,
)
from google.ads.googleads.v15.resources.types.topic_constant import TopicConstant
from google.ads.googleads.v15.resources.types.topic_view import TopicView
from google.ads.googleads.v15.resources.types.travel_activity_group_view import (
    TravelActivityGroupView,
)
from google.ads.googleads.v15.resources.types.travel_activity_performance_view import (
    TravelActivityPerformanceView,
)
from google.ads.googleads.v15.resources.types.user_interest import UserInterest
from google.ads.googleads.v15.resources.types.user_list import UserList
from google.ads.googleads.v15.resources.types.user_location_view import UserLocationView
from google.ads.googleads.v15.resources.types.video import Video
from google.ads.googleads.v15.resources.types.webpage_view import WebpageView
from google.ads.googleads.v15.services.types.ad_group_ad_label_service import (
    AdGroupAdLabelOperation,
    MutateAdGroupAdLabelResult,
)
from google.ads.googleads.v15.services.types.ad_group_ad_service import (
    AdGroupAdOperation,
    MutateAdGroupAdResult,
)
from google.ads.googleads.v15.services.types.ad_group_asset_service import (
    AdGroupAssetOperation,
    MutateAdGroupAssetResult,
)
from google.ads.googleads.v15.services.types.ad_group_bid_modifier_service import (
    AdGroupBidModifierOperation,
    MutateAdGroupBidModifierResult,
)
from google.ads.googleads.v15.services.types.ad_group_criterion_customizer_service import (
    AdGroupCriterionCustomizerOperation,
    MutateAdGroupCriterionCustomizerResult,
)
from google.ads.googleads.v15.services.types.ad_group_criterion_label_service import (
    AdGroupCriterionLabelOperation,
    MutateAdGroupCriterionLabelResult,
)
from google.ads.googleads.v15.services.types.ad_group_criterion_service import (
    AdGroupCriterionOperation,
    MutateAdGroupCriterionResult,
)
from google.ads.googleads.v15.services.types.ad_group_customizer_service import (
    AdGroupCustomizerOperation,
    MutateAdGroupCustomizerResult,
)
from google.ads.googleads.v15.services.types.ad_group_extension_setting_service import (
    AdGroupExtensionSettingOperation,
    MutateAdGroupExtensionSettingResult,
)
from google.ads.googleads.v15.services.types.ad_group_feed_service import (
    AdGroupFeedOperation,
    MutateAdGroupFeedResult,
)
from google.ads.googleads.v15.services.types.ad_group_label_service import (
    AdGroupLabelOperation,
    MutateAdGroupLabelResult,
)
from google.ads.googleads.v15.services.types.ad_group_service import (
    AdGroupOperation,
    MutateAdGroupResult,
)
from google.ads.googleads.v15.services.types.ad_parameter_service import (
    AdParameterOperation,
    MutateAdParameterResult,
)
from google.ads.googleads.v15.services.types.ad_service import (
    AdOperation,
    MutateAdResult,
)
from google.ads.googleads.v15.services.types.asset_group_asset_service import (
    AssetGroupAssetOperation,
    MutateAssetGroupAssetResult,
)
from google.ads.googleads.v15.services.types.asset_group_listing_group_filter_service import (
    AssetGroupListingGroupFilterOperation,
    MutateAssetGroupListingGroupFilterResult,
)
from google.ads.googleads.v15.services.types.asset_group_service import (
    AssetGroupOperation,
    MutateAssetGroupResult,
)
from google.ads.googleads.v15.services.types.asset_group_signal_service import (
    AssetGroupSignalOperation,
    MutateAssetGroupSignalResult,
)
from google.ads.googleads.v15.services.types.asset_service import (
    AssetOperation,
    MutateAssetResult,
)
from google.ads.googleads.v15.services.types.asset_set_asset_service import (
    AssetSetAssetOperation,
    MutateAssetSetAssetResult,
)
from google.ads.googleads.v15.services.types.asset_set_service import (
    AssetSetOperation,
    MutateAssetSetResult,
)
from google.ads.googleads.v15.services.types.audience_service import (
    AudienceOperation,
    MutateAudienceResult,
)
from google.ads.googleads.v15.services.types.bidding_data_exclusion_service import (
    BiddingDataExclusionOperation,
    MutateBiddingDataExclusionsResult,
)
from google.ads.googleads.v15.services.types.bidding_seasonality_adjustment_service import (
    BiddingSeasonalityAdjustmentOperation,
    MutateBiddingSeasonalityAdjustmentsResult,
)
from google.ads.googleads.v15.services.types.bidding_strategy_service import (
    BiddingStrategyOperation,
    MutateBiddingStrategyResult,
)
from google.ads.googleads.v15.services.types.campaign_asset_service import (
    CampaignAssetOperation,
    MutateCampaignAssetResult,
)
from google.ads.googleads.v15.services.types.campaign_asset_set_service import (
    CampaignAssetSetOperation,
    MutateCampaignAssetSetResult,
)
from google.ads.googleads.v15.services.types.campaign_bid_modifier_service import (
    CampaignBidModifierOperation,
    MutateCampaignBidModifierResult,
)
from google.ads.googleads.v15.services.types.campaign_budget_service import (
    CampaignBudgetOperation,
    MutateCampaignBudgetResult,
)
from google.ads.googleads.v15.services.types.campaign_conversion_goal_service import (
    CampaignConversionGoalOperation,
    MutateCampaignConversionGoalResult,
)
from google.ads.googleads.v15.services.types.campaign_criterion_service import (
    CampaignCriterionOperation,
    MutateCampaignCriterionResult,
)
from google.ads.googleads.v15.services.types.campaign_customizer_service import (
    CampaignCustomizerOperation,
    MutateCampaignCustomizerResult,
)
from google.ads.googleads.v15.services.types.campaign_draft_service import (
    CampaignDraftOperation,
    MutateCampaignDraftResult,
)
from google.ads.googleads.v15.services.types.campaign_extension_setting_service import (
    CampaignExtensionSettingOperation,
    MutateCampaignExtensionSettingResult,
)
from google.ads.googleads.v15.services.types.campaign_feed_service import (
    CampaignFeedOperation,
    MutateCampaignFeedResult,
)
from google.ads.googleads.v15.services.types.campaign_group_service import (
    CampaignGroupOperation,
    MutateCampaignGroupResult,
)
from google.ads.googleads.v15.services.types.campaign_label_service import (
    CampaignLabelOperation,
    MutateCampaignLabelResult,
)
from google.ads.googleads.v15.services.types.campaign_service import (
    CampaignOperation,
    MutateCampaignResult,
)
from google.ads.googleads.v15.services.types.campaign_shared_set_service import (
    CampaignSharedSetOperation,
    MutateCampaignSharedSetResult,
)
from google.ads.googleads.v15.services.types.conversion_action_service import (
    ConversionActionOperation,
    MutateConversionActionResult,
)
from google.ads.googleads.v15.services.types.conversion_custom_variable_service import (
    ConversionCustomVariableOperation,
    MutateConversionCustomVariableResult,
)
from google.ads.googleads.v15.services.types.conversion_goal_campaign_config_service import (
    ConversionGoalCampaignConfigOperation,
    MutateConversionGoalCampaignConfigResult,
)
from google.ads.googleads.v15.services.types.conversion_value_rule_service import (
    ConversionValueRuleOperation,
    MutateConversionValueRuleResult,
)
from google.ads.googleads.v15.services.types.conversion_value_rule_set_service import (
    ConversionValueRuleSetOperation,
    MutateConversionValueRuleSetResult,
)
from google.ads.googleads.v15.services.types.custom_conversion_goal_service import (
    CustomConversionGoalOperation,
    MutateCustomConversionGoalResult,
)
from google.ads.googleads.v15.services.types.customer_asset_service import (
    CustomerAssetOperation,
    MutateCustomerAssetResult,
)
from google.ads.googleads.v15.services.types.customer_conversion_goal_service import (
    CustomerConversionGoalOperation,
    MutateCustomerConversionGoalResult,
)
from google.ads.googleads.v15.services.types.customer_customizer_service import (
    CustomerCustomizerOperation,
    MutateCustomerCustomizerResult,
)
from google.ads.googleads.v15.services.types.customer_extension_setting_service import (
    CustomerExtensionSettingOperation,
    MutateCustomerExtensionSettingResult,
)
from google.ads.googleads.v15.services.types.customer_feed_service import (
    CustomerFeedOperation,
    MutateCustomerFeedResult,
)
from google.ads.googleads.v15.services.types.customer_label_service import (
    CustomerLabelOperation,
    MutateCustomerLabelResult,
)
from google.ads.googleads.v15.services.types.customer_negative_criterion_service import (
    CustomerNegativeCriterionOperation,
    MutateCustomerNegativeCriteriaResult,
)
from google.ads.googleads.v15.services.types.customer_service import (
    CustomerOperation,
    MutateCustomerResult,
)
from google.ads.googleads.v15.services.types.customizer_attribute_service import (
    CustomizerAttributeOperation,
    MutateCustomizerAttributeResult,
)
from google.ads.googleads.v15.services.types.experiment_arm_service import (
    ExperimentArmOperation,
    MutateExperimentArmResult,
)
from google.ads.googleads.v15.services.types.experiment_service import (
    ExperimentOperation,
    MutateExperimentResult,
)
from google.ads.googleads.v15.services.types.extension_feed_item_service import (
    ExtensionFeedItemOperation,
    MutateExtensionFeedItemResult,
)
from google.ads.googleads.v15.services.types.feed_item_service import (
    FeedItemOperation,
    MutateFeedItemResult,
)
from google.ads.googleads.v15.services.types.feed_item_set_link_service import (
    FeedItemSetLinkOperation,
    MutateFeedItemSetLinkResult,
)
from google.ads.googleads.v15.services.types.feed_item_set_service import (
    FeedItemSetOperation,
    MutateFeedItemSetResult,
)
from google.ads.googleads.v15.services.types.feed_item_target_service import (
    FeedItemTargetOperation,
    MutateFeedItemTargetResult,
)
from google.ads.googleads.v15.services.types.feed_mapping_service import (
    FeedMappingOperation,
    MutateFeedMappingResult,
)
from google.ads.googleads.v15.services.types.feed_service import (
    FeedOperation,
    MutateFeedResult,
)
from google.ads.googleads.v15.services.types.keyword_plan_ad_group_keyword_service import (
    KeywordPlanAdGroupKeywordOperation,
    MutateKeywordPlanAdGroupKeywordResult,
)
from google.ads.googleads.v15.services.types.keyword_plan_ad_group_service import (
    KeywordPlanAdGroupOperation,
    MutateKeywordPlanAdGroupResult,
)
from google.ads.googleads.v15.services.types.keyword_plan_campaign_keyword_service import (
    KeywordPlanCampaignKeywordOperation,
    MutateKeywordPlanCampaignKeywordResult,
)
from google.ads.googleads.v15.services.types.keyword_plan_campaign_service import (
    KeywordPlanCampaignOperation,
    MutateKeywordPlanCampaignResult,
)
from google.ads.googleads.v15.services.types.keyword_plan_service import (
    KeywordPlanOperation,
    MutateKeywordPlansResult,
)
from google.ads.googleads.v15.services.types.label_service import (
    LabelOperation,
    MutateLabelResult,
)
from google.ads.googleads.v15.services.types.recommendation_subscription_service import (
    MutateRecommendationSubscriptionResult,
    RecommendationSubscriptionOperation,
)
from google.ads.googleads.v15.services.types.remarketing_action_service import (
    MutateRemarketingActionResult,
    RemarketingActionOperation,
)
from google.ads.googleads.v15.services.types.shared_criterion_service import (
    MutateSharedCriterionResult,
    SharedCriterionOperation,
)
from google.ads.googleads.v15.services.types.shared_set_service import (
    MutateSharedSetResult,
    SharedSetOperation,
)
from google.ads.googleads.v15.services.types.smart_campaign_setting_service import (
    MutateSmartCampaignSettingResult,
    SmartCampaignSettingOperation,
)
from google.ads.googleads.v15.services.types.user_list_service import (
    MutateUserListResult,
    UserListOperation,
)

_M = TypeVar("_M")

class GoogleAdsRow(proto.Message):
    account_budget: AccountBudget
    account_budget_proposal: AccountBudgetProposal
    account_link: AccountLink
    ad_group: AdGroup
    ad_group_ad: AdGroupAd
    ad_group_ad_asset_combination_view: AdGroupAdAssetCombinationView
    ad_group_ad_asset_view: AdGroupAdAssetView
    ad_group_ad_label: AdGroupAdLabel
    ad_group_asset: AdGroupAsset
    ad_group_asset_set: AdGroupAssetSet
    ad_group_audience_view: AdGroupAudienceView
    ad_group_bid_modifier: AdGroupBidModifier
    ad_group_criterion: AdGroupCriterion
    ad_group_criterion_customizer: AdGroupCriterionCustomizer
    ad_group_criterion_label: AdGroupCriterionLabel
    ad_group_criterion_simulation: AdGroupCriterionSimulation
    ad_group_customizer: AdGroupCustomizer
    ad_group_extension_setting: AdGroupExtensionSetting
    ad_group_feed: AdGroupFeed
    ad_group_label: AdGroupLabel
    ad_group_simulation: AdGroupSimulation
    ad_parameter: AdParameter
    age_range_view: AgeRangeView
    ad_schedule_view: AdScheduleView
    domain_category: DomainCategory
    asset: Asset
    asset_field_type_view: AssetFieldTypeView
    asset_group_asset: AssetGroupAsset
    asset_group_signal: AssetGroupSignal
    asset_group_listing_group_filter: AssetGroupListingGroupFilter
    asset_group_product_group_view: AssetGroupProductGroupView
    asset_group_top_combination_view: AssetGroupTopCombinationView
    asset_group: AssetGroup
    asset_set_asset: AssetSetAsset
    asset_set: AssetSet
    asset_set_type_view: AssetSetTypeView
    batch_job: BatchJob
    bidding_data_exclusion: BiddingDataExclusion
    bidding_seasonality_adjustment: BiddingSeasonalityAdjustment
    bidding_strategy: BiddingStrategy
    bidding_strategy_simulation: BiddingStrategySimulation
    billing_setup: BillingSetup
    call_view: CallView
    campaign_budget: CampaignBudget
    campaign: Campaign
    campaign_asset: CampaignAsset
    campaign_asset_set: CampaignAssetSet
    campaign_audience_view: CampaignAudienceView
    campaign_bid_modifier: CampaignBidModifier
    campaign_conversion_goal: CampaignConversionGoal
    campaign_criterion: CampaignCriterion
    campaign_customizer: CampaignCustomizer
    campaign_draft: CampaignDraft
    campaign_extension_setting: CampaignExtensionSetting
    campaign_feed: CampaignFeed
    campaign_group: CampaignGroup
    campaign_label: CampaignLabel
    campaign_lifecycle_goal: CampaignLifecycleGoal
    campaign_search_term_insight: CampaignSearchTermInsight
    campaign_shared_set: CampaignSharedSet
    campaign_simulation: CampaignSimulation
    carrier_constant: CarrierConstant
    change_event: ChangeEvent
    change_status: ChangeStatus
    combined_audience: CombinedAudience
    audience: Audience
    conversion_action: ConversionAction
    conversion_custom_variable: ConversionCustomVariable
    conversion_goal_campaign_config: ConversionGoalCampaignConfig
    conversion_value_rule: ConversionValueRule
    conversion_value_rule_set: ConversionValueRuleSet
    click_view: ClickView
    currency_constant: CurrencyConstant
    custom_audience: CustomAudience
    custom_conversion_goal: CustomConversionGoal
    custom_interest: CustomInterest
    customer: Customer
    customer_asset: CustomerAsset
    customer_asset_set: CustomerAssetSet
    accessible_bidding_strategy: AccessibleBiddingStrategy
    customer_customizer: CustomerCustomizer
    customer_manager_link: CustomerManagerLink
    customer_client_link: CustomerClientLink
    customer_client: CustomerClient
    customer_conversion_goal: CustomerConversionGoal
    customer_extension_setting: CustomerExtensionSetting
    customer_feed: CustomerFeed
    customer_label: CustomerLabel
    customer_lifecycle_goal: CustomerLifecycleGoal
    customer_negative_criterion: CustomerNegativeCriterion
    customer_search_term_insight: CustomerSearchTermInsight
    customer_user_access: CustomerUserAccess
    customer_user_access_invitation: CustomerUserAccessInvitation
    customizer_attribute: CustomizerAttribute
    detail_placement_view: DetailPlacementView
    detailed_demographic: DetailedDemographic
    display_keyword_view: DisplayKeywordView
    distance_view: DistanceView
    dynamic_search_ads_search_term_view: DynamicSearchAdsSearchTermView
    expanded_landing_page_view: ExpandedLandingPageView
    extension_feed_item: ExtensionFeedItem
    feed: Feed
    feed_item: FeedItem
    feed_item_set: FeedItemSet
    feed_item_set_link: FeedItemSetLink
    feed_item_target: FeedItemTarget
    feed_mapping: FeedMapping
    feed_placeholder_view: FeedPlaceholderView
    gender_view: GenderView
    geo_target_constant: GeoTargetConstant
    geographic_view: GeographicView
    group_placement_view: GroupPlacementView
    hotel_group_view: HotelGroupView
    hotel_performance_view: HotelPerformanceView
    hotel_reconciliation: HotelReconciliation
    income_range_view: IncomeRangeView
    keyword_view: KeywordView
    keyword_plan: KeywordPlan
    keyword_plan_campaign: KeywordPlanCampaign
    keyword_plan_campaign_keyword: KeywordPlanCampaignKeyword
    keyword_plan_ad_group: KeywordPlanAdGroup
    keyword_plan_ad_group_keyword: KeywordPlanAdGroupKeyword
    keyword_theme_constant: KeywordThemeConstant
    label: Label
    landing_page_view: LandingPageView
    language_constant: LanguageConstant
    location_view: LocationView
    managed_placement_view: ManagedPlacementView
    media_file: MediaFile
    local_services_verification_artifact: LocalServicesVerificationArtifact
    mobile_app_category_constant: MobileAppCategoryConstant
    mobile_device_constant: MobileDeviceConstant
    offline_conversion_upload_client_summary: OfflineConversionUploadClientSummary
    offline_user_data_job: OfflineUserDataJob
    operating_system_version_constant: OperatingSystemVersionConstant
    paid_organic_search_term_view: PaidOrganicSearchTermView
    qualifying_question: QualifyingQuestion
    parental_status_view: ParentalStatusView
    per_store_view: PerStoreView
    product_category_constant: ProductCategoryConstant
    product_group_view: ProductGroupView
    product_link: ProductLink
    product_link_invitation: ProductLinkInvitation
    recommendation: Recommendation
    recommendation_subscription: RecommendationSubscription
    search_term_view: SearchTermView
    shared_criterion: SharedCriterion
    shared_set: SharedSet
    smart_campaign_setting: SmartCampaignSetting
    shopping_performance_view: ShoppingPerformanceView
    smart_campaign_search_term_view: SmartCampaignSearchTermView
    third_party_app_analytics_link: ThirdPartyAppAnalyticsLink
    topic_view: TopicView
    travel_activity_group_view: TravelActivityGroupView
    travel_activity_performance_view: TravelActivityPerformanceView
    experiment: Experiment
    experiment_arm: ExperimentArm
    user_interest: UserInterest
    life_event: LifeEvent
    user_list: UserList
    user_location_view: UserLocationView
    remarketing_action: RemarketingAction
    topic_constant: TopicConstant
    video: Video
    webpage_view: WebpageView
    lead_form_submission_data: LeadFormSubmissionData
    local_services_lead: LocalServicesLead
    local_services_lead_conversation: LocalServicesLeadConversation
    android_privacy_shared_key_google_ad_group: AndroidPrivacySharedKeyGoogleAdGroup
    android_privacy_shared_key_google_campaign: AndroidPrivacySharedKeyGoogleCampaign
    android_privacy_shared_key_google_network_type: AndroidPrivacySharedKeyGoogleNetworkType
    metrics: Metrics
    segments: Segments
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        account_budget: AccountBudget = ...,
        account_budget_proposal: AccountBudgetProposal = ...,
        account_link: AccountLink = ...,
        ad_group: AdGroup = ...,
        ad_group_ad: AdGroupAd = ...,
        ad_group_ad_asset_combination_view: AdGroupAdAssetCombinationView = ...,
        ad_group_ad_asset_view: AdGroupAdAssetView = ...,
        ad_group_ad_label: AdGroupAdLabel = ...,
        ad_group_asset: AdGroupAsset = ...,
        ad_group_asset_set: AdGroupAssetSet = ...,
        ad_group_audience_view: AdGroupAudienceView = ...,
        ad_group_bid_modifier: AdGroupBidModifier = ...,
        ad_group_criterion: AdGroupCriterion = ...,
        ad_group_criterion_customizer: AdGroupCriterionCustomizer = ...,
        ad_group_criterion_label: AdGroupCriterionLabel = ...,
        ad_group_criterion_simulation: AdGroupCriterionSimulation = ...,
        ad_group_customizer: AdGroupCustomizer = ...,
        ad_group_extension_setting: AdGroupExtensionSetting = ...,
        ad_group_feed: AdGroupFeed = ...,
        ad_group_label: AdGroupLabel = ...,
        ad_group_simulation: AdGroupSimulation = ...,
        ad_parameter: AdParameter = ...,
        age_range_view: AgeRangeView = ...,
        ad_schedule_view: AdScheduleView = ...,
        domain_category: DomainCategory = ...,
        asset: Asset = ...,
        asset_field_type_view: AssetFieldTypeView = ...,
        asset_group_asset: AssetGroupAsset = ...,
        asset_group_signal: AssetGroupSignal = ...,
        asset_group_listing_group_filter: AssetGroupListingGroupFilter = ...,
        asset_group_product_group_view: AssetGroupProductGroupView = ...,
        asset_group_top_combination_view: AssetGroupTopCombinationView = ...,
        asset_group: AssetGroup = ...,
        asset_set_asset: AssetSetAsset = ...,
        asset_set: AssetSet = ...,
        asset_set_type_view: AssetSetTypeView = ...,
        batch_job: BatchJob = ...,
        bidding_data_exclusion: BiddingDataExclusion = ...,
        bidding_seasonality_adjustment: BiddingSeasonalityAdjustment = ...,
        bidding_strategy: BiddingStrategy = ...,
        bidding_strategy_simulation: BiddingStrategySimulation = ...,
        billing_setup: BillingSetup = ...,
        call_view: CallView = ...,
        campaign_budget: CampaignBudget = ...,
        campaign: Campaign = ...,
        campaign_asset: CampaignAsset = ...,
        campaign_asset_set: CampaignAssetSet = ...,
        campaign_audience_view: CampaignAudienceView = ...,
        campaign_bid_modifier: CampaignBidModifier = ...,
        campaign_conversion_goal: CampaignConversionGoal = ...,
        campaign_criterion: CampaignCriterion = ...,
        campaign_customizer: CampaignCustomizer = ...,
        campaign_draft: CampaignDraft = ...,
        campaign_extension_setting: CampaignExtensionSetting = ...,
        campaign_feed: CampaignFeed = ...,
        campaign_group: CampaignGroup = ...,
        campaign_label: CampaignLabel = ...,
        campaign_lifecycle_goal: CampaignLifecycleGoal = ...,
        campaign_search_term_insight: CampaignSearchTermInsight = ...,
        campaign_shared_set: CampaignSharedSet = ...,
        campaign_simulation: CampaignSimulation = ...,
        carrier_constant: CarrierConstant = ...,
        change_event: ChangeEvent = ...,
        change_status: ChangeStatus = ...,
        combined_audience: CombinedAudience = ...,
        audience: Audience = ...,
        conversion_action: ConversionAction = ...,
        conversion_custom_variable: ConversionCustomVariable = ...,
        conversion_goal_campaign_config: ConversionGoalCampaignConfig = ...,
        conversion_value_rule: ConversionValueRule = ...,
        conversion_value_rule_set: ConversionValueRuleSet = ...,
        click_view: ClickView = ...,
        currency_constant: CurrencyConstant = ...,
        custom_audience: CustomAudience = ...,
        custom_conversion_goal: CustomConversionGoal = ...,
        custom_interest: CustomInterest = ...,
        customer: Customer = ...,
        customer_asset: CustomerAsset = ...,
        customer_asset_set: CustomerAssetSet = ...,
        accessible_bidding_strategy: AccessibleBiddingStrategy = ...,
        customer_customizer: CustomerCustomizer = ...,
        customer_manager_link: CustomerManagerLink = ...,
        customer_client_link: CustomerClientLink = ...,
        customer_client: CustomerClient = ...,
        customer_conversion_goal: CustomerConversionGoal = ...,
        customer_extension_setting: CustomerExtensionSetting = ...,
        customer_feed: CustomerFeed = ...,
        customer_label: CustomerLabel = ...,
        customer_lifecycle_goal: CustomerLifecycleGoal = ...,
        customer_negative_criterion: CustomerNegativeCriterion = ...,
        customer_search_term_insight: CustomerSearchTermInsight = ...,
        customer_user_access: CustomerUserAccess = ...,
        customer_user_access_invitation: CustomerUserAccessInvitation = ...,
        customizer_attribute: CustomizerAttribute = ...,
        detail_placement_view: DetailPlacementView = ...,
        detailed_demographic: DetailedDemographic = ...,
        display_keyword_view: DisplayKeywordView = ...,
        distance_view: DistanceView = ...,
        dynamic_search_ads_search_term_view: DynamicSearchAdsSearchTermView = ...,
        expanded_landing_page_view: ExpandedLandingPageView = ...,
        extension_feed_item: ExtensionFeedItem = ...,
        feed: Feed = ...,
        feed_item: FeedItem = ...,
        feed_item_set: FeedItemSet = ...,
        feed_item_set_link: FeedItemSetLink = ...,
        feed_item_target: FeedItemTarget = ...,
        feed_mapping: FeedMapping = ...,
        feed_placeholder_view: FeedPlaceholderView = ...,
        gender_view: GenderView = ...,
        geo_target_constant: GeoTargetConstant = ...,
        geographic_view: GeographicView = ...,
        group_placement_view: GroupPlacementView = ...,
        hotel_group_view: HotelGroupView = ...,
        hotel_performance_view: HotelPerformanceView = ...,
        hotel_reconciliation: HotelReconciliation = ...,
        income_range_view: IncomeRangeView = ...,
        keyword_view: KeywordView = ...,
        keyword_plan: KeywordPlan = ...,
        keyword_plan_campaign: KeywordPlanCampaign = ...,
        keyword_plan_campaign_keyword: KeywordPlanCampaignKeyword = ...,
        keyword_plan_ad_group: KeywordPlanAdGroup = ...,
        keyword_plan_ad_group_keyword: KeywordPlanAdGroupKeyword = ...,
        keyword_theme_constant: KeywordThemeConstant = ...,
        label: Label = ...,
        landing_page_view: LandingPageView = ...,
        language_constant: LanguageConstant = ...,
        location_view: LocationView = ...,
        managed_placement_view: ManagedPlacementView = ...,
        media_file: MediaFile = ...,
        local_services_verification_artifact: LocalServicesVerificationArtifact = ...,
        mobile_app_category_constant: MobileAppCategoryConstant = ...,
        mobile_device_constant: MobileDeviceConstant = ...,
        offline_conversion_upload_client_summary: OfflineConversionUploadClientSummary = ...,
        offline_user_data_job: OfflineUserDataJob = ...,
        operating_system_version_constant: OperatingSystemVersionConstant = ...,
        paid_organic_search_term_view: PaidOrganicSearchTermView = ...,
        qualifying_question: QualifyingQuestion = ...,
        parental_status_view: ParentalStatusView = ...,
        per_store_view: PerStoreView = ...,
        product_category_constant: ProductCategoryConstant = ...,
        product_group_view: ProductGroupView = ...,
        product_link: ProductLink = ...,
        product_link_invitation: ProductLinkInvitation = ...,
        recommendation: Recommendation = ...,
        recommendation_subscription: RecommendationSubscription = ...,
        search_term_view: SearchTermView = ...,
        shared_criterion: SharedCriterion = ...,
        shared_set: SharedSet = ...,
        smart_campaign_setting: SmartCampaignSetting = ...,
        shopping_performance_view: ShoppingPerformanceView = ...,
        smart_campaign_search_term_view: SmartCampaignSearchTermView = ...,
        third_party_app_analytics_link: ThirdPartyAppAnalyticsLink = ...,
        topic_view: TopicView = ...,
        travel_activity_group_view: TravelActivityGroupView = ...,
        travel_activity_performance_view: TravelActivityPerformanceView = ...,
        experiment: Experiment = ...,
        experiment_arm: ExperimentArm = ...,
        user_interest: UserInterest = ...,
        life_event: LifeEvent = ...,
        user_list: UserList = ...,
        user_location_view: UserLocationView = ...,
        remarketing_action: RemarketingAction = ...,
        topic_constant: TopicConstant = ...,
        video: Video = ...,
        webpage_view: WebpageView = ...,
        lead_form_submission_data: LeadFormSubmissionData = ...,
        local_services_lead: LocalServicesLead = ...,
        local_services_lead_conversation: LocalServicesLeadConversation = ...,
        android_privacy_shared_key_google_ad_group: AndroidPrivacySharedKeyGoogleAdGroup = ...,
        android_privacy_shared_key_google_campaign: AndroidPrivacySharedKeyGoogleCampaign = ...,
        android_privacy_shared_key_google_network_type: AndroidPrivacySharedKeyGoogleNetworkType = ...,
        metrics: Metrics = ...,
        segments: Segments = ...
    ) -> None: ...

class MutateGoogleAdsRequest(proto.Message):
    customer_id: str
    mutate_operations: MutableSequence[MutateOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        mutate_operations: MutableSequence[MutateOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...
    ) -> None: ...

class MutateGoogleAdsResponse(proto.Message):
    partial_failure_error: Status
    mutate_operation_responses: MutableSequence[MutateOperationResponse]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        partial_failure_error: Status = ...,
        mutate_operation_responses: MutableSequence[MutateOperationResponse] = ...
    ) -> None: ...

class MutateOperation(proto.Message):
    ad_group_ad_label_operation: AdGroupAdLabelOperation
    ad_group_ad_operation: AdGroupAdOperation
    ad_group_asset_operation: AdGroupAssetOperation
    ad_group_bid_modifier_operation: AdGroupBidModifierOperation
    ad_group_criterion_customizer_operation: AdGroupCriterionCustomizerOperation
    ad_group_criterion_label_operation: AdGroupCriterionLabelOperation
    ad_group_criterion_operation: AdGroupCriterionOperation
    ad_group_customizer_operation: AdGroupCustomizerOperation
    ad_group_extension_setting_operation: AdGroupExtensionSettingOperation
    ad_group_feed_operation: AdGroupFeedOperation
    ad_group_label_operation: AdGroupLabelOperation
    ad_group_operation: AdGroupOperation
    ad_operation: AdOperation
    ad_parameter_operation: AdParameterOperation
    asset_operation: AssetOperation
    asset_group_asset_operation: AssetGroupAssetOperation
    asset_group_listing_group_filter_operation: AssetGroupListingGroupFilterOperation
    asset_group_signal_operation: AssetGroupSignalOperation
    asset_group_operation: AssetGroupOperation
    asset_set_asset_operation: AssetSetAssetOperation
    asset_set_operation: AssetSetOperation
    audience_operation: AudienceOperation
    bidding_data_exclusion_operation: BiddingDataExclusionOperation
    bidding_seasonality_adjustment_operation: BiddingSeasonalityAdjustmentOperation
    bidding_strategy_operation: BiddingStrategyOperation
    campaign_asset_operation: CampaignAssetOperation
    campaign_asset_set_operation: CampaignAssetSetOperation
    campaign_bid_modifier_operation: CampaignBidModifierOperation
    campaign_budget_operation: CampaignBudgetOperation
    campaign_conversion_goal_operation: CampaignConversionGoalOperation
    campaign_criterion_operation: CampaignCriterionOperation
    campaign_customizer_operation: CampaignCustomizerOperation
    campaign_draft_operation: CampaignDraftOperation
    campaign_extension_setting_operation: CampaignExtensionSettingOperation
    campaign_feed_operation: CampaignFeedOperation
    campaign_group_operation: CampaignGroupOperation
    campaign_label_operation: CampaignLabelOperation
    campaign_operation: CampaignOperation
    campaign_shared_set_operation: CampaignSharedSetOperation
    conversion_action_operation: ConversionActionOperation
    conversion_custom_variable_operation: ConversionCustomVariableOperation
    conversion_goal_campaign_config_operation: ConversionGoalCampaignConfigOperation
    conversion_value_rule_operation: ConversionValueRuleOperation
    conversion_value_rule_set_operation: ConversionValueRuleSetOperation
    custom_conversion_goal_operation: CustomConversionGoalOperation
    customer_asset_operation: CustomerAssetOperation
    customer_conversion_goal_operation: CustomerConversionGoalOperation
    customer_customizer_operation: CustomerCustomizerOperation
    customer_extension_setting_operation: CustomerExtensionSettingOperation
    customer_feed_operation: CustomerFeedOperation
    customer_label_operation: CustomerLabelOperation
    customer_negative_criterion_operation: CustomerNegativeCriterionOperation
    customer_operation: CustomerOperation
    customizer_attribute_operation: CustomizerAttributeOperation
    experiment_operation: ExperimentOperation
    experiment_arm_operation: ExperimentArmOperation
    extension_feed_item_operation: ExtensionFeedItemOperation
    feed_item_operation: FeedItemOperation
    feed_item_set_operation: FeedItemSetOperation
    feed_item_set_link_operation: FeedItemSetLinkOperation
    feed_item_target_operation: FeedItemTargetOperation
    feed_mapping_operation: FeedMappingOperation
    feed_operation: FeedOperation
    keyword_plan_ad_group_operation: KeywordPlanAdGroupOperation
    keyword_plan_ad_group_keyword_operation: KeywordPlanAdGroupKeywordOperation
    keyword_plan_campaign_keyword_operation: KeywordPlanCampaignKeywordOperation
    keyword_plan_campaign_operation: KeywordPlanCampaignOperation
    keyword_plan_operation: KeywordPlanOperation
    label_operation: LabelOperation
    recommendation_subscription_operation: RecommendationSubscriptionOperation
    remarketing_action_operation: RemarketingActionOperation
    shared_criterion_operation: SharedCriterionOperation
    shared_set_operation: SharedSetOperation
    smart_campaign_setting_operation: SmartCampaignSettingOperation
    user_list_operation: UserListOperation
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        ad_group_ad_label_operation: AdGroupAdLabelOperation = ...,
        ad_group_ad_operation: AdGroupAdOperation = ...,
        ad_group_asset_operation: AdGroupAssetOperation = ...,
        ad_group_bid_modifier_operation: AdGroupBidModifierOperation = ...,
        ad_group_criterion_customizer_operation: AdGroupCriterionCustomizerOperation = ...,
        ad_group_criterion_label_operation: AdGroupCriterionLabelOperation = ...,
        ad_group_criterion_operation: AdGroupCriterionOperation = ...,
        ad_group_customizer_operation: AdGroupCustomizerOperation = ...,
        ad_group_extension_setting_operation: AdGroupExtensionSettingOperation = ...,
        ad_group_feed_operation: AdGroupFeedOperation = ...,
        ad_group_label_operation: AdGroupLabelOperation = ...,
        ad_group_operation: AdGroupOperation = ...,
        ad_operation: AdOperation = ...,
        ad_parameter_operation: AdParameterOperation = ...,
        asset_operation: AssetOperation = ...,
        asset_group_asset_operation: AssetGroupAssetOperation = ...,
        asset_group_listing_group_filter_operation: AssetGroupListingGroupFilterOperation = ...,
        asset_group_signal_operation: AssetGroupSignalOperation = ...,
        asset_group_operation: AssetGroupOperation = ...,
        asset_set_asset_operation: AssetSetAssetOperation = ...,
        asset_set_operation: AssetSetOperation = ...,
        audience_operation: AudienceOperation = ...,
        bidding_data_exclusion_operation: BiddingDataExclusionOperation = ...,
        bidding_seasonality_adjustment_operation: BiddingSeasonalityAdjustmentOperation = ...,
        bidding_strategy_operation: BiddingStrategyOperation = ...,
        campaign_asset_operation: CampaignAssetOperation = ...,
        campaign_asset_set_operation: CampaignAssetSetOperation = ...,
        campaign_bid_modifier_operation: CampaignBidModifierOperation = ...,
        campaign_budget_operation: CampaignBudgetOperation = ...,
        campaign_conversion_goal_operation: CampaignConversionGoalOperation = ...,
        campaign_criterion_operation: CampaignCriterionOperation = ...,
        campaign_customizer_operation: CampaignCustomizerOperation = ...,
        campaign_draft_operation: CampaignDraftOperation = ...,
        campaign_extension_setting_operation: CampaignExtensionSettingOperation = ...,
        campaign_feed_operation: CampaignFeedOperation = ...,
        campaign_group_operation: CampaignGroupOperation = ...,
        campaign_label_operation: CampaignLabelOperation = ...,
        campaign_operation: CampaignOperation = ...,
        campaign_shared_set_operation: CampaignSharedSetOperation = ...,
        conversion_action_operation: ConversionActionOperation = ...,
        conversion_custom_variable_operation: ConversionCustomVariableOperation = ...,
        conversion_goal_campaign_config_operation: ConversionGoalCampaignConfigOperation = ...,
        conversion_value_rule_operation: ConversionValueRuleOperation = ...,
        conversion_value_rule_set_operation: ConversionValueRuleSetOperation = ...,
        custom_conversion_goal_operation: CustomConversionGoalOperation = ...,
        customer_asset_operation: CustomerAssetOperation = ...,
        customer_conversion_goal_operation: CustomerConversionGoalOperation = ...,
        customer_customizer_operation: CustomerCustomizerOperation = ...,
        customer_extension_setting_operation: CustomerExtensionSettingOperation = ...,
        customer_feed_operation: CustomerFeedOperation = ...,
        customer_label_operation: CustomerLabelOperation = ...,
        customer_negative_criterion_operation: CustomerNegativeCriterionOperation = ...,
        customer_operation: CustomerOperation = ...,
        customizer_attribute_operation: CustomizerAttributeOperation = ...,
        experiment_operation: ExperimentOperation = ...,
        experiment_arm_operation: ExperimentArmOperation = ...,
        extension_feed_item_operation: ExtensionFeedItemOperation = ...,
        feed_item_operation: FeedItemOperation = ...,
        feed_item_set_operation: FeedItemSetOperation = ...,
        feed_item_set_link_operation: FeedItemSetLinkOperation = ...,
        feed_item_target_operation: FeedItemTargetOperation = ...,
        feed_mapping_operation: FeedMappingOperation = ...,
        feed_operation: FeedOperation = ...,
        keyword_plan_ad_group_operation: KeywordPlanAdGroupOperation = ...,
        keyword_plan_ad_group_keyword_operation: KeywordPlanAdGroupKeywordOperation = ...,
        keyword_plan_campaign_keyword_operation: KeywordPlanCampaignKeywordOperation = ...,
        keyword_plan_campaign_operation: KeywordPlanCampaignOperation = ...,
        keyword_plan_operation: KeywordPlanOperation = ...,
        label_operation: LabelOperation = ...,
        recommendation_subscription_operation: RecommendationSubscriptionOperation = ...,
        remarketing_action_operation: RemarketingActionOperation = ...,
        shared_criterion_operation: SharedCriterionOperation = ...,
        shared_set_operation: SharedSetOperation = ...,
        smart_campaign_setting_operation: SmartCampaignSettingOperation = ...,
        user_list_operation: UserListOperation = ...
    ) -> None: ...

class MutateOperationResponse(proto.Message):
    ad_group_ad_label_result: MutateAdGroupAdLabelResult
    ad_group_ad_result: MutateAdGroupAdResult
    ad_group_asset_result: MutateAdGroupAssetResult
    ad_group_bid_modifier_result: MutateAdGroupBidModifierResult
    ad_group_criterion_customizer_result: MutateAdGroupCriterionCustomizerResult
    ad_group_criterion_label_result: MutateAdGroupCriterionLabelResult
    ad_group_criterion_result: MutateAdGroupCriterionResult
    ad_group_customizer_result: MutateAdGroupCustomizerResult
    ad_group_extension_setting_result: MutateAdGroupExtensionSettingResult
    ad_group_feed_result: MutateAdGroupFeedResult
    ad_group_label_result: MutateAdGroupLabelResult
    ad_group_result: MutateAdGroupResult
    ad_parameter_result: MutateAdParameterResult
    ad_result: MutateAdResult
    asset_result: MutateAssetResult
    asset_group_asset_result: MutateAssetGroupAssetResult
    asset_group_listing_group_filter_result: MutateAssetGroupListingGroupFilterResult
    asset_group_signal_result: MutateAssetGroupSignalResult
    asset_group_result: MutateAssetGroupResult
    asset_set_asset_result: MutateAssetSetAssetResult
    asset_set_result: MutateAssetSetResult
    audience_result: MutateAudienceResult
    bidding_data_exclusion_result: MutateBiddingDataExclusionsResult
    bidding_seasonality_adjustment_result: MutateBiddingSeasonalityAdjustmentsResult
    bidding_strategy_result: MutateBiddingStrategyResult
    campaign_asset_result: MutateCampaignAssetResult
    campaign_asset_set_result: MutateCampaignAssetSetResult
    campaign_bid_modifier_result: MutateCampaignBidModifierResult
    campaign_budget_result: MutateCampaignBudgetResult
    campaign_conversion_goal_result: MutateCampaignConversionGoalResult
    campaign_criterion_result: MutateCampaignCriterionResult
    campaign_customizer_result: MutateCampaignCustomizerResult
    campaign_draft_result: MutateCampaignDraftResult
    campaign_extension_setting_result: MutateCampaignExtensionSettingResult
    campaign_feed_result: MutateCampaignFeedResult
    campaign_group_result: MutateCampaignGroupResult
    campaign_label_result: MutateCampaignLabelResult
    campaign_result: MutateCampaignResult
    campaign_shared_set_result: MutateCampaignSharedSetResult
    conversion_action_result: MutateConversionActionResult
    conversion_custom_variable_result: MutateConversionCustomVariableResult
    conversion_goal_campaign_config_result: MutateConversionGoalCampaignConfigResult
    conversion_value_rule_result: MutateConversionValueRuleResult
    conversion_value_rule_set_result: MutateConversionValueRuleSetResult
    custom_conversion_goal_result: MutateCustomConversionGoalResult
    customer_asset_result: MutateCustomerAssetResult
    customer_conversion_goal_result: MutateCustomerConversionGoalResult
    customer_customizer_result: MutateCustomerCustomizerResult
    customer_extension_setting_result: MutateCustomerExtensionSettingResult
    customer_feed_result: MutateCustomerFeedResult
    customer_label_result: MutateCustomerLabelResult
    customer_negative_criterion_result: MutateCustomerNegativeCriteriaResult
    customer_result: MutateCustomerResult
    customizer_attribute_result: MutateCustomizerAttributeResult
    experiment_result: MutateExperimentResult
    experiment_arm_result: MutateExperimentArmResult
    extension_feed_item_result: MutateExtensionFeedItemResult
    feed_item_result: MutateFeedItemResult
    feed_item_set_result: MutateFeedItemSetResult
    feed_item_set_link_result: MutateFeedItemSetLinkResult
    feed_item_target_result: MutateFeedItemTargetResult
    feed_mapping_result: MutateFeedMappingResult
    feed_result: MutateFeedResult
    keyword_plan_ad_group_result: MutateKeywordPlanAdGroupResult
    keyword_plan_campaign_result: MutateKeywordPlanCampaignResult
    keyword_plan_ad_group_keyword_result: MutateKeywordPlanAdGroupKeywordResult
    keyword_plan_campaign_keyword_result: MutateKeywordPlanCampaignKeywordResult
    keyword_plan_result: MutateKeywordPlansResult
    label_result: MutateLabelResult
    recommendation_subscription_result: MutateRecommendationSubscriptionResult
    remarketing_action_result: MutateRemarketingActionResult
    shared_criterion_result: MutateSharedCriterionResult
    shared_set_result: MutateSharedSetResult
    smart_campaign_setting_result: MutateSmartCampaignSettingResult
    user_list_result: MutateUserListResult
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        ad_group_ad_label_result: MutateAdGroupAdLabelResult = ...,
        ad_group_ad_result: MutateAdGroupAdResult = ...,
        ad_group_asset_result: MutateAdGroupAssetResult = ...,
        ad_group_bid_modifier_result: MutateAdGroupBidModifierResult = ...,
        ad_group_criterion_customizer_result: MutateAdGroupCriterionCustomizerResult = ...,
        ad_group_criterion_label_result: MutateAdGroupCriterionLabelResult = ...,
        ad_group_criterion_result: MutateAdGroupCriterionResult = ...,
        ad_group_customizer_result: MutateAdGroupCustomizerResult = ...,
        ad_group_extension_setting_result: MutateAdGroupExtensionSettingResult = ...,
        ad_group_feed_result: MutateAdGroupFeedResult = ...,
        ad_group_label_result: MutateAdGroupLabelResult = ...,
        ad_group_result: MutateAdGroupResult = ...,
        ad_parameter_result: MutateAdParameterResult = ...,
        ad_result: MutateAdResult = ...,
        asset_result: MutateAssetResult = ...,
        asset_group_asset_result: MutateAssetGroupAssetResult = ...,
        asset_group_listing_group_filter_result: MutateAssetGroupListingGroupFilterResult = ...,
        asset_group_signal_result: MutateAssetGroupSignalResult = ...,
        asset_group_result: MutateAssetGroupResult = ...,
        asset_set_asset_result: MutateAssetSetAssetResult = ...,
        asset_set_result: MutateAssetSetResult = ...,
        audience_result: MutateAudienceResult = ...,
        bidding_data_exclusion_result: MutateBiddingDataExclusionsResult = ...,
        bidding_seasonality_adjustment_result: MutateBiddingSeasonalityAdjustmentsResult = ...,
        bidding_strategy_result: MutateBiddingStrategyResult = ...,
        campaign_asset_result: MutateCampaignAssetResult = ...,
        campaign_asset_set_result: MutateCampaignAssetSetResult = ...,
        campaign_bid_modifier_result: MutateCampaignBidModifierResult = ...,
        campaign_budget_result: MutateCampaignBudgetResult = ...,
        campaign_conversion_goal_result: MutateCampaignConversionGoalResult = ...,
        campaign_criterion_result: MutateCampaignCriterionResult = ...,
        campaign_customizer_result: MutateCampaignCustomizerResult = ...,
        campaign_draft_result: MutateCampaignDraftResult = ...,
        campaign_extension_setting_result: MutateCampaignExtensionSettingResult = ...,
        campaign_feed_result: MutateCampaignFeedResult = ...,
        campaign_group_result: MutateCampaignGroupResult = ...,
        campaign_label_result: MutateCampaignLabelResult = ...,
        campaign_result: MutateCampaignResult = ...,
        campaign_shared_set_result: MutateCampaignSharedSetResult = ...,
        conversion_action_result: MutateConversionActionResult = ...,
        conversion_custom_variable_result: MutateConversionCustomVariableResult = ...,
        conversion_goal_campaign_config_result: MutateConversionGoalCampaignConfigResult = ...,
        conversion_value_rule_result: MutateConversionValueRuleResult = ...,
        conversion_value_rule_set_result: MutateConversionValueRuleSetResult = ...,
        custom_conversion_goal_result: MutateCustomConversionGoalResult = ...,
        customer_asset_result: MutateCustomerAssetResult = ...,
        customer_conversion_goal_result: MutateCustomerConversionGoalResult = ...,
        customer_customizer_result: MutateCustomerCustomizerResult = ...,
        customer_extension_setting_result: MutateCustomerExtensionSettingResult = ...,
        customer_feed_result: MutateCustomerFeedResult = ...,
        customer_label_result: MutateCustomerLabelResult = ...,
        customer_negative_criterion_result: MutateCustomerNegativeCriteriaResult = ...,
        customer_result: MutateCustomerResult = ...,
        customizer_attribute_result: MutateCustomizerAttributeResult = ...,
        experiment_result: MutateExperimentResult = ...,
        experiment_arm_result: MutateExperimentArmResult = ...,
        extension_feed_item_result: MutateExtensionFeedItemResult = ...,
        feed_item_result: MutateFeedItemResult = ...,
        feed_item_set_result: MutateFeedItemSetResult = ...,
        feed_item_set_link_result: MutateFeedItemSetLinkResult = ...,
        feed_item_target_result: MutateFeedItemTargetResult = ...,
        feed_mapping_result: MutateFeedMappingResult = ...,
        feed_result: MutateFeedResult = ...,
        keyword_plan_ad_group_result: MutateKeywordPlanAdGroupResult = ...,
        keyword_plan_campaign_result: MutateKeywordPlanCampaignResult = ...,
        keyword_plan_ad_group_keyword_result: MutateKeywordPlanAdGroupKeywordResult = ...,
        keyword_plan_campaign_keyword_result: MutateKeywordPlanCampaignKeywordResult = ...,
        keyword_plan_result: MutateKeywordPlansResult = ...,
        label_result: MutateLabelResult = ...,
        recommendation_subscription_result: MutateRecommendationSubscriptionResult = ...,
        remarketing_action_result: MutateRemarketingActionResult = ...,
        shared_criterion_result: MutateSharedCriterionResult = ...,
        shared_set_result: MutateSharedSetResult = ...,
        smart_campaign_setting_result: MutateSmartCampaignSettingResult = ...,
        user_list_result: MutateUserListResult = ...
    ) -> None: ...

class SearchGoogleAdsRequest(proto.Message):
    customer_id: str
    query: str
    page_token: str
    page_size: int
    validate_only: bool
    return_total_results_count: bool
    summary_row_setting: SummaryRowSettingEnum.SummaryRowSetting
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        query: str = ...,
        page_token: str = ...,
        page_size: int = ...,
        validate_only: bool = ...,
        return_total_results_count: bool = ...,
        summary_row_setting: SummaryRowSettingEnum.SummaryRowSetting = ...
    ) -> None: ...

class SearchGoogleAdsResponse(proto.Message):
    results: MutableSequence[GoogleAdsRow]
    next_page_token: str
    total_results_count: int
    field_mask: FieldMask
    summary_row: GoogleAdsRow
    query_resource_consumption: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        results: MutableSequence[GoogleAdsRow] = ...,
        next_page_token: str = ...,
        total_results_count: int = ...,
        field_mask: FieldMask = ...,
        summary_row: GoogleAdsRow = ...,
        query_resource_consumption: int = ...
    ) -> None: ...

class SearchGoogleAdsStreamRequest(proto.Message):
    customer_id: str
    query: str
    summary_row_setting: SummaryRowSettingEnum.SummaryRowSetting
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        query: str = ...,
        summary_row_setting: SummaryRowSettingEnum.SummaryRowSetting = ...
    ) -> None: ...

class SearchGoogleAdsStreamResponse(proto.Message):
    results: MutableSequence[GoogleAdsRow]
    field_mask: FieldMask
    summary_row: GoogleAdsRow
    request_id: str
    query_resource_consumption: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        results: MutableSequence[GoogleAdsRow] = ...,
        field_mask: FieldMask = ...,
        summary_row: GoogleAdsRow = ...,
        request_id: str = ...,
        query_resource_consumption: int = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class ConversionActionTypeEnum(proto.Message):
    class ConversionActionType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        AD_CALL = 2
        CLICK_TO_CALL = 3
        GOOGLE_PLAY_DOWNLOAD = 4
        GOOGLE_PLAY_IN_APP_PURCHASE = 5
        UPLOAD_CALLS = 6
        UPLOAD_CLICKS = 7
        WEBPAGE = 8
        WEBSITE_CALL = 9
        STORE_SALES_DIRECT_UPLOAD = 10
        STORE_SALES = 11
        FIREBASE_ANDROID_FIRST_OPEN = 12
        FIREBASE_ANDROID_IN_APP_PURCHASE = 13
        FIREBASE_ANDROID_CUSTOM = 14
        FIREBASE_IOS_FIRST_OPEN = 15
        FIREBASE_IOS_IN_APP_PURCHASE = 16
        FIREBASE_IOS_CUSTOM = 17
        THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN = 18
        THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE = 19
        THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM = 20
        THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN = 21
        THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE = 22
        THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM = 23
        ANDROID_APP_PRE_REGISTRATION = 24
        ANDROID_INSTALLS_ALL_OTHER_APPS = 25
        FLOODLIGHT_ACTION = 26
        FLOODLIGHT_TRANSACTION = 27
        GOOGLE_HOSTED = 28
        LEAD_FORM_SUBMIT = 29
        SALESFORCE = 30
        SEARCH_ADS_360 = 31
        SMART_CAMPAIGN_AD_CLICKS_TO_CALL = 32
        SMART_CAMPAIGN_MAP_CLICKS_TO_CALL = 33
        SMART_CAMPAIGN_MAP_DIRECTIONS = 34
        SMART_CAMPAIGN_TRACKED_CALLS = 35
        STORE_VISITS = 36
        WEBPAGE_CODELESS = 37
        UNIVERSAL_ANALYTICS_GOAL = 38
        UNIVERSAL_ANALYTICS_TRANSACTION = 39
        GOOGLE_ANALYTICS_4_CUSTOM = 40
        GOOGLE_ANALYTICS_4_PURCHASE = 41
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v14.common.types.criteria import AdScheduleInfo, KeywordInfo
from google.ads.googleads.v14.enums.types.feed_item_target_device import (
    FeedItemTargetDeviceEnum,
)
from google.ads.googleads.v14.enums.types.feed_item_target_status import (
    FeedItemTargetStatusEnum,
)
from google.ads.googleads.v14.enums.types.feed_item_target_type import (
    FeedItemTargetTypeEnum,
)

_M = TypeVar("_M")

class FeedItemTarget(proto.Message):
    resource_name: str
    feed_item: str
    feed_item_target_type: FeedItemTargetTypeEnum.FeedItemTargetType
    feed_item_target_id: int
    status: FeedItemTargetStatusEnum.FeedItemTargetStatus
    campaign: str
    ad_group: str
    keyword: KeywordInfo
    geo_target_constant: str
    device: FeedItemTargetDeviceEnum.FeedItemTargetDevice
    ad_schedule: AdScheduleInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        feed_item: str = ...,
        feed_item_target_type: FeedItemTargetTypeEnum.FeedItemTargetType = ...,
        feed_item_target_id: int = ...,
        status: FeedItemTargetStatusEnum.FeedItemTargetStatus = ...,
        campaign: str = ...,
        ad_group: str = ...,
        keyword: KeywordInfo = ...,
        geo_target_constant: str = ...,
        device: FeedItemTargetDeviceEnum.FeedItemTargetDevice = ...,
        ad_schedule: AdScheduleInfo = ...
    ) -> None: ...



from .base import (
    CampaignCustomizerServiceTransport as CampaignCustomizerServiceTransport,
)
from .grpc import (
    CampaignCustomizerServiceGrpcTransport as CampaignCustomizerServiceGrpcTransport,
)



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v15.enums.types.change_status_operation import (
    ChangeStatusOperationEnum,
)
from google.ads.googleads.v15.enums.types.change_status_resource_type import (
    ChangeStatusResourceTypeEnum,
)

_M = TypeVar("_M")

class ChangeStatus(proto.Message):
    resource_name: str
    last_change_date_time: str
    resource_type: ChangeStatusResourceTypeEnum.ChangeStatusResourceType
    campaign: str
    ad_group: str
    resource_status: ChangeStatusOperationEnum.ChangeStatusOperation
    ad_group_ad: str
    ad_group_criterion: str
    campaign_criterion: str
    feed: str
    feed_item: str
    ad_group_feed: str
    campaign_feed: str
    ad_group_bid_modifier: str
    shared_set: str
    campaign_shared_set: str
    asset: str
    customer_asset: str
    campaign_asset: str
    ad_group_asset: str
    combined_audience: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        last_change_date_time: str = ...,
        resource_type: ChangeStatusResourceTypeEnum.ChangeStatusResourceType = ...,
        campaign: str = ...,
        ad_group: str = ...,
        resource_status: ChangeStatusOperationEnum.ChangeStatusOperation = ...,
        ad_group_ad: str = ...,
        ad_group_criterion: str = ...,
        campaign_criterion: str = ...,
        feed: str = ...,
        feed_item: str = ...,
        ad_group_feed: str = ...,
        campaign_feed: str = ...,
        ad_group_bid_modifier: str = ...,
        shared_set: str = ...,
        campaign_shared_set: str = ...,
        asset: str = ...,
        customer_asset: str = ...,
        campaign_asset: str = ...,
        ad_group_asset: str = ...,
        combined_audience: str = ...
    ) -> None: ...



import abc
from typing import Awaitable, Callable, Optional, Sequence, Union

from _typeshed import Incomplete
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v14.services.types import account_link_service

class AccountLinkServiceTransport(abc.ABC):
    AUTH_SCOPES: Incomplete
    DEFAULT_HOST: str
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: Optional[ga_credentials.Credentials] = ...,
        credentials_file: Optional[str] = ...,
        scopes: Optional[Sequence[str]] = ...,
        quota_project_id: Optional[str] = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: Optional[bool] = ...,
        **kwargs
    ) -> None: ...
    def close(self) -> None: ...
    @property
    def create_account_link(
        self,
    ) -> Callable[
        [account_link_service.CreateAccountLinkRequest],
        Union[
            account_link_service.CreateAccountLinkResponse,
            Awaitable[account_link_service.CreateAccountLinkResponse],
        ],
    ]: ...
    @property
    def mutate_account_link(
        self,
    ) -> Callable[
        [account_link_service.MutateAccountLinkRequest],
        Union[
            account_link_service.MutateAccountLinkResponse,
            Awaitable[account_link_service.MutateAccountLinkResponse],
        ],
    ]: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v15.enums.types.media_type import MediaTypeEnum
from google.ads.googleads.v15.enums.types.mime_type import MimeTypeEnum

_M = TypeVar("_M")

class MediaAudio(proto.Message):
    ad_duration_millis: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        ad_duration_millis: int = ...
    ) -> None: ...

class MediaBundle(proto.Message):
    data: bytes
    url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        data: bytes = ...,
        url: str = ...
    ) -> None: ...

class MediaFile(proto.Message):
    resource_name: str
    id: int
    type_: MediaTypeEnum.MediaType
    mime_type: MimeTypeEnum.MimeType
    source_url: str
    name: str
    file_size: int
    image: MediaImage
    media_bundle: MediaBundle
    audio: MediaAudio
    video: MediaVideo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        id: int = ...,
        type_: MediaTypeEnum.MediaType = ...,
        mime_type: MimeTypeEnum.MimeType = ...,
        source_url: str = ...,
        name: str = ...,
        file_size: int = ...,
        image: MediaImage = ...,
        media_bundle: MediaBundle = ...,
        audio: MediaAudio = ...,
        video: MediaVideo = ...
    ) -> None: ...

class MediaImage(proto.Message):
    data: bytes
    full_size_image_url: str
    preview_size_image_url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        data: bytes = ...,
        full_size_image_url: str = ...,
        preview_size_image_url: str = ...
    ) -> None: ...

class MediaVideo(proto.Message):
    ad_duration_millis: int
    youtube_video_id: str
    advertising_id_code: str
    isci_code: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        ad_duration_millis: int = ...,
        youtube_video_id: str = ...,
        advertising_id_code: str = ...,
        isci_code: str = ...
    ) -> None: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status

from google.ads.googleads.v15.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v15.resources.types.campaign_customizer import (
    CampaignCustomizer,
)

_M = TypeVar("_M")

class CampaignCustomizerOperation(proto.Message):
    create: CampaignCustomizer
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        create: CampaignCustomizer = ...,
        remove: str = ...
    ) -> None: ...

class MutateCampaignCustomizerResult(proto.Message):
    resource_name: str
    campaign_customizer: CampaignCustomizer
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        campaign_customizer: CampaignCustomizer = ...
    ) -> None: ...

class MutateCampaignCustomizersRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[CampaignCustomizerOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer_id: str = ...,
        operations: MutableSequence[CampaignCustomizerOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...
    ) -> None: ...

class MutateCampaignCustomizersResponse(proto.Message):
    results: MutableSequence[MutateCampaignCustomizerResult]
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        results: MutableSequence[MutateCampaignCustomizerResult] = ...,
        partial_failure_error: Status = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class AdGroupErrorEnum(proto.Message):
    class AdGroupError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        DUPLICATE_ADGROUP_NAME = 2
        INVALID_ADGROUP_NAME = 3
        ADVERTISER_NOT_ON_CONTENT_NETWORK = 5
        BID_TOO_BIG = 6
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = 7
        MISSING_ADGROUP_NAME = 8
        ADGROUP_LABEL_DOES_NOT_EXIST = 9
        ADGROUP_LABEL_ALREADY_EXISTS = 10
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = 11
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = 12
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = 13
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = 14
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = 15
        INVALID_EXCLUDED_PARENT_ASSET_FIELD_TYPE = 16
        INVALID_EXCLUDED_PARENT_ASSET_SET_TYPE = 17
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...



from .base import (
    MerchantCenterLinkServiceTransport as MerchantCenterLinkServiceTransport,
)
from .grpc import (
    MerchantCenterLinkServiceGrpcTransport as MerchantCenterLinkServiceGrpcTransport,
)



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v15.enums.types.account_link_status import (
    AccountLinkStatusEnum,
)
from google.ads.googleads.v15.enums.types.linked_account_type import (
    LinkedAccountTypeEnum,
)
from google.ads.googleads.v15.enums.types.mobile_app_vendor import MobileAppVendorEnum

_M = TypeVar("_M")

class AccountLink(proto.Message):
    resource_name: str
    account_link_id: int
    status: AccountLinkStatusEnum.AccountLinkStatus
    type_: LinkedAccountTypeEnum.LinkedAccountType
    third_party_app_analytics: ThirdPartyAppAnalyticsLinkIdentifier
    data_partner: DataPartnerLinkIdentifier
    google_ads: GoogleAdsLinkIdentifier
    advertising_partner: AdvertisingPartnerLinkIdentifier
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        account_link_id: int = ...,
        status: AccountLinkStatusEnum.AccountLinkStatus = ...,
        type_: LinkedAccountTypeEnum.LinkedAccountType = ...,
        third_party_app_analytics: ThirdPartyAppAnalyticsLinkIdentifier = ...,
        data_partner: DataPartnerLinkIdentifier = ...,
        google_ads: GoogleAdsLinkIdentifier = ...,
        advertising_partner: AdvertisingPartnerLinkIdentifier = ...
    ) -> None: ...

class AdvertisingPartnerLinkIdentifier(proto.Message):
    customer: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer: str = ...
    ) -> None: ...

class DataPartnerLinkIdentifier(proto.Message):
    data_partner_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        data_partner_id: int = ...
    ) -> None: ...

class GoogleAdsLinkIdentifier(proto.Message):
    customer: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        customer: str = ...
    ) -> None: ...

class ThirdPartyAppAnalyticsLinkIdentifier(proto.Message):
    app_analytics_provider_id: int
    app_id: str
    app_vendor: MobileAppVendorEnum.MobileAppVendor
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        app_analytics_provider_id: int = ...,
        app_id: str = ...,
        app_vendor: MobileAppVendorEnum.MobileAppVendor = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

from google.ads.googleads.v13.common.types.offline_user_data import (
    CustomerMatchUserListMetadata,
    StoreSalesMetadata,
)
from google.ads.googleads.v13.enums.types.offline_user_data_job_failure_reason import (
    OfflineUserDataJobFailureReasonEnum,
)
from google.ads.googleads.v13.enums.types.offline_user_data_job_match_rate_range import (
    OfflineUserDataJobMatchRateRangeEnum,
)
from google.ads.googleads.v13.enums.types.offline_user_data_job_status import (
    OfflineUserDataJobStatusEnum,
)
from google.ads.googleads.v13.enums.types.offline_user_data_job_type import (
    OfflineUserDataJobTypeEnum,
)

_M = TypeVar("_M")

class OfflineUserDataJob(proto.Message):
    resource_name: str
    id: int
    external_id: int
    type_: OfflineUserDataJobTypeEnum.OfflineUserDataJobType
    status: OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus
    failure_reason: OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason
    operation_metadata: OfflineUserDataJobMetadata
    customer_match_user_list_metadata: CustomerMatchUserListMetadata
    store_sales_metadata: StoreSalesMetadata
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        resource_name: str = ...,
        id: int = ...,
        external_id: int = ...,
        type_: OfflineUserDataJobTypeEnum.OfflineUserDataJobType = ...,
        status: OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus = ...,
        failure_reason: OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason = ...,
        operation_metadata: OfflineUserDataJobMetadata = ...,
        customer_match_user_list_metadata: CustomerMatchUserListMetadata = ...,
        store_sales_metadata: StoreSalesMetadata = ...
    ) -> None: ...

class OfflineUserDataJobMetadata(proto.Message):
    match_rate_range: OfflineUserDataJobMatchRateRangeEnum.OfflineUserDataJobMatchRateRange
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
        match_rate_range: OfflineUserDataJobMatchRateRangeEnum.OfflineUserDataJobMatchRateRange = ...
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, TypeVar

import google.protobuf.message
import proto

_M = TypeVar("_M")

class ExperimentArmErrorEnum(proto.Message):
    class ExperimentArmError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        EXPERIMENT_ARM_COUNT_LIMIT_EXCEEDED = 2
        INVALID_CAMPAIGN_STATUS = 3
        DUPLICATE_EXPERIMENT_ARM_NAME = 4
        CANNOT_SET_TREATMENT_ARM_CAMPAIGN = 5
        CANNOT_MODIFY_CAMPAIGN_IDS = 6
        CANNOT_MODIFY_CAMPAIGN_WITHOUT_SUFFIX_SET = 7
        CANNOT_MUTATE_TRAFFIC_SPLIT_AFTER_START = 8
        CANNOT_ADD_CAMPAIGN_WITH_SHARED_BUDGET = 9
        CANNOT_ADD_CAMPAIGN_WITH_CUSTOM_BUDGET = 10
        CANNOT_ADD_CAMPAIGNS_WITH_DYNAMIC_ASSETS_ENABLED = 11
        UNSUPPORTED_CAMPAIGN_ADVERTISING_CHANNEL_SUB_TYPE = 12
        CANNOT_ADD_BASE_CAMPAIGN_WITH_DATE_RANGE = 13
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_EXPERIMENTS = 14
        TRAFFIC_SPLIT_NOT_SUPPORTED_FOR_CHANNEL_TYPE = 15
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = ...,
        *,
        ignore_unknown_fields: bool = ...,
    ) -> None: ...
